/*
ssc (static site checker)
Copyright (c) 2020,2021 Dylan Harris
https://dylanharris.org/

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public Licence as published by
the Free Software Foundation, either version 3 of the Licence,  or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public Licence for more details.

You should have received a copy of the GNU General Public
Licence along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#include "main/standard.h"
#include "parser/text.h"
#include "utility/common.h"
#include "feedback/nitpick.h"

struct wotsit_t
{   html_version first_, last_;
    const char* wotsit_ = nullptr;
    const char* char_ = nullptr;
    wotsit_t () = default;
    wotsit_t (html_version first, html_version last, const char* wotsit, const char* sz = nullptr)
        :   first_ (first), last_ (last), wotsit_ (wotsit), char_ (sz) { }
    wotsit_t (const wotsit_t& w) = default;
#ifndef NO_MOVE_CONSTRUCTOR
    wotsit_t (wotsit_t&& w) = default;
    wotsit_t& operator = (wotsit_t&& w) = default;
#endif // NO_MOVE_CONSTRUCTOR
    ~wotsit_t () = default;
    wotsit_t& operator = (const wotsit_t& w) = default; };

wotsit_t wotsit_table [] =
{   { { HTML_1_0 }, { HTML_UNDEF }, "AElig", "Æ" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Aacute", "À" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Abreve" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Acirc", "Å" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Acy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Afr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Agr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Agrave", "À" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Alpha", "" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Amacr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "And" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Aogon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Aopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ApplyFunction" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Aring" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ascr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Assign" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Atilde", "Ã" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Auml", "Ä" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Backslash", "\\" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "BadBreak" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Barv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Barwed" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Bcy" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Because" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Bernoullis" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Beta" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Bfr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Bgr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Bopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Breve" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Bscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Bumpeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "CHcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "COPY", "©" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Cacute" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Cap" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CapitalDifferentialD" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Cayleys" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ccaron" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Ccedil", "Ç" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ccirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Cconint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Cdot" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Cedilla", "¸" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CenterDot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Cfr" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Chi" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CircleDot" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CircleMinus" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CirclePlus" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CircleTimes" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ClockwiseContourIntegral" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CloseCurlyDoubleQuote" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CloseCurlyQuote" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Colon", ":" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Colone" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Congruent" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Conint" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ContourIntegral" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Copf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Coproduct" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CounterClockwiseContourIntegral" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Cross" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Cscr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Cup" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "CupCap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "DD" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "DDotrahd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "DJcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "DScy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "DZcy" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Dagger" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Darr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Dashv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Dcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Dcy" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Del" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Delta" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Dfr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalAcute" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalDot" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalDoubleAcute" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalGrave" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalLeftArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalLeftRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalLeftRightVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalLeftVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalRightVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DiacriticalTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Diamond" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DifferentialD" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Dopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Dot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "DotDot" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DotEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleContourIntegral" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleDot" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleDownArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleLeftArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleLeftRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleLeftTee" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleLongLeftArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleLongLeftRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleLongRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleRightTee" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleUpArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleUpDownArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DoubleVerticalBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownArrowBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownArrowUpArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownBreve" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownLeftRightVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownLeftTeeVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownLeftVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownLeftVectorBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownRightTeeVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownRightVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownRightVectorBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownTee" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "DownTeeArrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Downarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Dscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Dstrok" },
    { { HTML_PLUS }, { HTML_PLUS }, "EEgr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ENG" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ETH" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Eacute", "É" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ecaron" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Ecirc", "Ê" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ecy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Edot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Efr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Egr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Egrave", "È" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Element" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Emacr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "EmptySmallSquare" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "EmptyVerySmallSquare" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Eogon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Eopf" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Epsilon" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Equal" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "EqualTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Equilibrium" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Escr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Esim" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Eta" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Euml" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Exists" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ExponentialE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Fcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ffr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "FilledSmallSquare" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "FilledVerySmallSquare" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Fopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ForAll" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Fouriertrf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Fscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "GJcy" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Gamma" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gammad" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gbreve" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gcedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gg" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "GoodBreak" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "GreaterEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "GreaterEqualLess" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "GreaterFullEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "GreaterGreater" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "GreaterLess" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "GreaterSlantEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "GreaterTilde" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Gt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "HARDcy" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Hacek" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Hat" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Hcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Hfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "HilbertSpace" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Hopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "HorizontalLine" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Hscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Hstrok" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "HumpDownHump" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "HumpEqual" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "IEcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "IJlig" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "IOcy" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Iacute", "Í" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Icirc", "Í" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Icy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Idot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ifr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Igr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Igrave", "Ì" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Im" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Imacr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ImaginaryI" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Implies" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "IndentingNewLine" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Int" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Integral" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Intersection" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "InvisibleComma" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "InvisibleTimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Iogon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Iopf" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Iota" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Iscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Itilde" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Iukcy" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Iuml" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Jcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Jcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Jfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Jopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Jscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Jsercy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Jukcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "KHcy" },
    { { HTML_PLUS }, { HTML_PLUS }, "KHgr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "KJcy" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Kappa" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Kcedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Kcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Kfr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Kgr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Kopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Kscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "LJcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lacute" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Lambda" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lang" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Laplacetrf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Larr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lcedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lcy" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftAngleBracket" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftArrowBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftArrowRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftBracketingBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftCeiling" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftDoubleBracket" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftDoubleBracketingBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftDownTeeVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftDownVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftDownVectorBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftFloor" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftRightVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftSkeleton" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftTee" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftTeeArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftTeeVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftTriangle" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftTriangleBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftTriangleEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftUpDownVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftUpTeeVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftUpVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftUpVectorBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LeftVectorBar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Leftarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Leftrightarrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LessEqualGreater" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LessFullEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LessGreater" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LessLess" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LessSlantEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LessTilde" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ll" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lleftarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lmidot" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LongLeftArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LongLeftRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LongRightArrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Longleftarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Longleftrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Longrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LowerLeftArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "LowerRightArrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lsh" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lstrok" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Lt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Map" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Mcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "MediumSpace" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Mellintrf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Mfr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Mgr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "MinusPlus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Mopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Mscr" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Mu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "NJcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Nacute" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NaN" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ncaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ncedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ncy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "NegativeMediumSpace" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "NegativeThickSpace" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "NegativeThinSpace" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "NegativeVeryThinSpace" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NestedGreaterGreater" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NestedLessLess" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NewLine" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Nfr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Ngr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "NoBreak" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "NonBreakingSpace" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Nopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Not" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotANumber" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotCongruent" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotCupCap" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotDoubleVerticalBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotElement" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotEqualTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotExists" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotGreater" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotGreaterEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotGreaterFullEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotGreaterGreater" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotGreaterLess" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotGreaterSlantEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotGreaterTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotHumpDownHump" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotHumpEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLeftTriangle" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLeftTriangleBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLeftTriangleEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLess" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLessEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLessFullEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLessGreater" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLessLess" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLessSlantEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotLessTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotNestedGreaterGreater" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotNestedLessLess" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotPrecedes" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotPrecedesEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotPrecedesSlantEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotPrecedesTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotReverseElement" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotRightTriangle" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotRightTriangleBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotRightTriangleEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSquareSubset" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSquareSubsetEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSquareSuperset" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSquareSupersetEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSubset" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSubsetEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSucceeds" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSucceedsEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSucceedsSlantEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSucceedsTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSuperset" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotSupersetEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotTildeEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotTildeFullEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotTildeTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "NotVerticalBar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Nscr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Ntilde", "Ñ" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Nu" },
    { { HTML_4_0 }, { HTML_UNDEF }, "OElig", "Œ" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Oacute", "Ó" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Ocirc", "Ô" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ocy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Odblac" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ofr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Ogr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Ograve", "Ò" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Omacr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Omega" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Omicron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Oopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "OpenCurlyDoubleQuote" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "OpenCurlyQuote" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Or" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Oscr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Oslash" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Otilde", "Õ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Otimes" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Ouml" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "OverBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "OverBrace" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "OverBracket" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "OverParenthesis" },
    { { HTML_PLUS }, { HTML_PLUS }, "PHgr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "PartialD" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Pcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Pfr" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Phi" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Pi", "∏" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "PlusMinus", "±" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Poincareplane" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Popf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Pr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Precedes" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "PrecedesEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "PrecedesSlantEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "PrecedesTilde" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Prime", "”" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Product" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Proportion" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Proportional" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Pscr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Psi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "QUOT" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Qfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Qopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Qscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "RBarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "REG" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Racute" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rang" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rarrtl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rcedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Re" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ReverseElement" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ReverseEquilibrium" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ReverseUpEquilibrium" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rfr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Rgr" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Rho" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightAngleBracket" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightArrowBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightArrowLeftArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightBracketingBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightCeiling" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightDoubleBracket" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightDoubleBracketingBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightDownTeeVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightDownVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightDownVectorBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightFloor" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightSkeleton" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightTee" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightTeeArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightTeeVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightTriangle" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightTriangleBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightTriangleEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightUpDownVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightUpTeeVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightUpVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightUpVectorBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightVector" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RightVectorBar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ropf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "RoundImplies" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Rsh" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "RuleDelayed" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "SHCHcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "SHcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "SOFTcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Sacute" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Sc" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Scaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Scedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Scirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Scy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Sfr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ShortDownArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ShortLeftArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ShortRightArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ShortUpArrow" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Sigma" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SmallCircle" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Sopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Space" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Sqrt" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Square" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SquareIntersection" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SquareSubset" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SquareSubsetEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SquareSuperset" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SquareSupersetEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SquareUnion" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Sscr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Star" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Sub" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Subset" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SubsetEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Succeeds" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SucceedsEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SucceedsSlantEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SucceedsTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SuchThat" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Sum" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Sup" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Superset" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "SupersetEqual" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Supset" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Tab" },
    { { HTML_1_0 }, { HTML_UNDEF }, "THORN" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "TRADE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "TSHcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "TScy" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Tau" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Tcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Tcedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Tcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Tfr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Tgr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Therefore" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Theta" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ThinSpace" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "ThickSpace" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Tilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "TildeEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "TildeFullEqual" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "TildeTilde" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Topf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "TripleDot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Tscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Tstrok" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Uacute", "Ú" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Uarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Uarrocir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ubrcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ubreve" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Ucirc", "Û" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ucy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Udblac" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ufr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Ugrave", "Ù" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Umacr" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UnderBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UnderBrace" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UnderBracket" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UnderParenthesis" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Union" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UnionPlus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Uogon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Uopf" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UpArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UpArrowBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UpArrowDownArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UpDownArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UpEquilibrium" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UpTee" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UpTeeArrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Uparrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Updownarrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UpperLeftArrow" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "UpperRightArrow" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Upsi" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Upsilon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Uring" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Uscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Utilde" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Uuml", "Ü" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "VDash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Vbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Vcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Vdash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Vdashl" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Vee" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Verbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Vert" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "VerticalBar" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "VerticalLine" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "VerticalSeparator" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "VerticalTilde" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "VeryThinSpace" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Vfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Vopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Vscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Vvdash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Wcirc" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "Wedge" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Wfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Wopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Wscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Xfr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "Xi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Xopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Xscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "YAcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "YIcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "YUcy" },
    { { HTML_1_0 }, { HTML_UNDEF }, "Yacute" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ycirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Ycy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Yfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Yopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Yscr" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Yuml", "Ÿ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ZHcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Zacute" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Zcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Zcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Zdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ZeroWidthSpace" },
    { { HTML_4_0 }, { HTML_UNDEF }, "Zeta" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Zfr" },
    { { HTML_PLUS }, { HTML_PLUS }, "Zgr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Zopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "Zscr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "aacute", "á" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "abreve" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ac" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "acd" },
    { { HTML_1_0 }, { HTML_UNDEF }, "acirc", "å" },
    { { HTML_1_0 }, { HTML_UNDEF }, "acute", "´" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "acy" },
    { { HTML_1_0 }, { HTML_UNDEF }, "aelig", "æ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "af" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "afr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "agrave", "à" },
    { { HTML_4_0 }, { HTML_UNDEF }, "alefsym" },
    { { HTML_PLUS }, { HTML_UNDEF }, "aleph" },
    { { HTML_PLUS }, { HTML_UNDEF }, "alpha" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "amacr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "amalg" },
    { { HTML_TAGS }, { HTML_UNDEF }, "amp", "" },
    { { HTML_PLUS }, { HTML_UNDEF }, "and" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "andand" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "andd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "andslope" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "andv" },
    { { HTML_PLUS }, { HTML_UNDEF }, "ang" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ange" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angle" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angmsd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angmsdaa" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angmsdab" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angmsdac" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angmsdad" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angmsdae" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angmsdaf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angmsdag" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angmsdah" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angrt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angrtvb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angrtvbd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angsph" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angst" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "angzarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "aogon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "aopf" },
    { { HTML_PLUS }, { HTML_UNDEF }, "ap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "apE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "apacir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ape" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "apid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "apos" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "approx" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "approxeq" },
    { { HTML_1_0 }, { HTML_UNDEF }, "aring" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ascr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ast" },
    { { HTML_4_0 }, { HTML_UNDEF }, "asymp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "asympeq" },
    { { HTML_1_0 }, { HTML_UNDEF }, "atilde", "ã" },
    { { HTML_1_0 }, { HTML_UNDEF }, "auml", "ä" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "awconint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "awint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bNot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "backcong" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "backepsilon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "backprime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "backsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "backsimeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "barvee" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "barwed" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "barwedge" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bbrk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bbrktbrk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bcong" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bcy" },
    { { HTML_4_0 }, { HTML_UNDEF }, "bdquo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "becaus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "because" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bemptyv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bepsi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bernou" },
    { { HTML_PLUS }, { HTML_UNDEF }, "beta", "ß" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "beth" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "between" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigcap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigcup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigodot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigoplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigotimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigsqcup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigstar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigtriangledown" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigtriangleup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "biguplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigvee" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bigwedge" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bkarow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blacklozenge" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blacksquare" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blacktriangle" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blacktriangledown" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blacktriangleleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blacktriangleright" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blank" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blk12" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blk14" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "blk34" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "block" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bnot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bottom" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bowtie" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxDL" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxDR" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxDl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxDr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxH" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxHD" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxHU" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxHd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxHu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxUL" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxUR" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxUl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxUr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxV" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxVH" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxVL" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxVR" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxVh" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxVl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxVr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxbox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxdL" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxdR" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxdl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxdr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxh" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxhD" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxhU" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxhd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxhu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxminus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxtimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxuL" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxuR" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxul" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxur" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxvH" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxvL" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxvR" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxvh" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxvl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "boxvr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bprime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "breve" },
    { { HTML_1_0 }, { HTML_UNDEF }, "brvbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bsemi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bsime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bsol" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bsolb" },
    { { HTML_PLUS }, { HTML_UNDEF }, "bull" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bullet" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bump" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bumpE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bumpe" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "bumpeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cacute" },
    { { HTML_PLUS }, { HTML_UNDEF }, "cap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "capand" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "capbrcup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "capcap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "capcup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "capdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "caret" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "caron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ccaps" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ccaron" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ccedil", "ç" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ccirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ccups" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ccupssm" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cdot" },
    { { HTML_3_0 }, { HTML_3_0 }, "cdots" },
    { { HTML_1_0 }, { HTML_UNDEF }, "cedil", "¸" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cemptyv" },
    { { HTML_1_0 }, { HTML_UNDEF }, "cent", "¢" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "centerdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "chcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "check" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "checkmark" },
    { { HTML_PLUS }, { HTML_UNDEF }, "chi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cirE" },
    { { HTML_4_0 }, { HTML_UNDEF }, "circ", "¨" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "circeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "circlearrowleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "circlearrowright" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "circledR" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "circledS" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "circledast" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "circledcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "circleddash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cire" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cirfnint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cirmid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cirscir" },
    { { HTML_PLUS }, { HTML_UNDEF }, "clubs" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "clubsuit" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "colon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "colone" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "coloneq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "comma", "," },
    { { HTML_JAN05 }, { HTML_UNDEF }, "commat" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "comp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "compfn" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "complement" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "complexes" },
    { { HTML_PLUS }, { HTML_UNDEF }, "cong" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "congdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "conint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "copf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "coprod" },
    { { HTML_1_0 }, { HTML_UNDEF }, "copy", "©" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "copysr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "cr", "\r" },
    { { HTML_4_0 }, { HTML_UNDEF }, "crarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cross", "†" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "csub" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "csube" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "csup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "csupe" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ctdot" },
    { { HTML_3_0 }, { HTML_3_0 }, "cub" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cudarrl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cudarrr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cuepr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cuesc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cularr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cularrp" },
    { { HTML_PLUS }, { HTML_UNDEF }, "cup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cupbrcap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cupcap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cupcup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cupdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cupor" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "curarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "curarrm" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "curlyeqprec" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "curlyeqsucc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "curlyvee" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "curlywedge" },
    { { HTML_1_0 }, { HTML_UNDEF }, "curren", "€" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "curvearrowleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "curvearrowright" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cuvee" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cuwed" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cwconint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cwint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "cylcty" },
    { { HTML_4_0 }, { HTML_UNDEF }, "dArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dHar" },
    { { HTML_4_0 }, { HTML_UNDEF }, "dagger" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "daleth" },
    { { HTML_PLUS }, { HTML_UNDEF }, "darr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dashv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dbkarow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dblac" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dcy" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "dd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ddagger" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ddarr" },
    { { HTML_3_0 }, { HTML_3_0 }, "ddots" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ddotseq" },
    { { HTML_1_0 }, { HTML_UNDEF }, "deg", "˚" },
    { { HTML_PLUS }, { HTML_PLUS }, "degree", "˚" },
    { { HTML_PLUS }, { HTML_UNDEF }, "delta", "∂" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "demptyv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dfisht" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dharl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dharr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "diam" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "diamond" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "diamondsuit" },
    { { HTML_PLUS }, { HTML_UNDEF }, "diams" },
    { { HTML_PLUS }, { HTML_UNDEF }, "die", "¨" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "digamma" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "disin" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "div" },
    { { HTML_1_0 }, { HTML_UNDEF }, "divide", "÷" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "divideontimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "divonx" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "djcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dlcorn" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dlcrop" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dollar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "doteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "doteqdot" },
    { { HTML_3_0 }, { HTML_3_0 }, "dotfill" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dotminus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dotplus" },
    { { HTML_3_0 }, { HTML_3_0 }, "dots" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dotsquare" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "doublebarwedge" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "downarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "downdownarrows" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "downharpoonleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "downharpoonright" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "drbkarow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "drcorn" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "drcrop" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dscy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dsol" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dstrok" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dtdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dtri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dtrif" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "duarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "duhar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dwangle" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dzcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "dzigrarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eDDot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eDot" },
    { { HTML_1_0 }, { HTML_UNDEF }, "eacute", "é" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "easter" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ecaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ecir" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ecirc", "ê" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ecolon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ecy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "edot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ee" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "efDot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "efr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eg" },
    { { HTML_1_0 }, { HTML_UNDEF }, "egrave", "è" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "egs" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "egsdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "el" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "elinters" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ell" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "els" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "elsdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "emacr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "empty" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "emptyset" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "emptyv" },
    { { HTML_3_0, HV_NOT32 }, { HTML_UNDEF }, "emsp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "emsp13" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "emsp14" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eng" },
    { { HTML_3_0, HV_NOT32 }, { HTML_UNDEF }, "ensp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eogon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "epar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eparsl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eplus" },
    { { HTML_PLUS }, { HTML_UNDEF }, "epsi" },
    { { HTML_3_0 }, { HTML_UNDEF }, "epsilon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "epsiv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eqcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eqcolon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eqsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eqslantgtr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eqslantless" },
    { { HTML_3_0 }, { HTML_UNDEF }, "equals" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "equest" },
    { { HTML_PLUS }, { HTML_UNDEF }, "equiv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "equivDD" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "eqvparsl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "erDot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "erarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "escr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "esdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "esim" },
    { { HTML_PLUS }, { HTML_UNDEF }, "eta" },
    { { HTML_1_0 }, { HTML_UNDEF }, "eth" },
    { { HTML_1_0 }, { HTML_UNDEF }, "euml", "ë" },
    { { HTML_4_0 }, { HTML_UNDEF }, "euro", "€" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "excl" },
    { { HTML_PLUS }, { HTML_UNDEF }, "exist" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "expectation" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "exponentiale" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "fallingdotseq" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "false" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "fcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "female" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ffilig" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "fflig" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ffllig" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ffr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "filig", "ﬁ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "flat" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "fllig", "ﬂ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "fltns" },
    { { HTML_4_0 }, { HTML_UNDEF }, "fnof", "ƒ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "fopf" },
    { { HTML_PLUS }, { HTML_UNDEF }, "forall" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "fork" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "forkv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "fpartint" },
    { { HTML_1_0 }, { HTML_UNDEF }, "frac12" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac13" },
    { { HTML_1_0 }, { HTML_UNDEF }, "frac14" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac15" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac16" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac18" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac23" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac25" },
    { { HTML_1_0 }, { HTML_UNDEF }, "frac34" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac35" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac38" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac45" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac56" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac58" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frac78" },
    { { HTML_4_0 }, { HTML_UNDEF }, "frasl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "frown" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "fscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gEl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gacute" },
    { { HTML_PLUS }, { HTML_UNDEF }, "gamma" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gammad" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gbreve" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gdot" },
    { { HTML_PLUS }, { HTML_UNDEF }, "ge", "≥" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gel" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "geq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "geqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "geqslant" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ges" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gescc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gesdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gesdoto" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gesdotol" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gesles" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gg" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ggg" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gimel" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gjcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "glE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gla" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "glj" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gnE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gnap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gnapprox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gne" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gneq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gneqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gnsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "grave", "`" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gsime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gsiml" },
    { { HTML_TAGS }, { HTML_UNDEF }, "gt", ">" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtcc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtcir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtlPar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtquest" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtrapprox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtrarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtrdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtreqless" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtreqqless" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtrless" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "gtrsim" },
    { { HTML_PLUS}, { HTML_UNDEF }, "hArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hairsp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "half" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hamilt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hardcy" },
    { { HTML_PLUS }, { HTML_UNDEF }, "harr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "harrcir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "harrw" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hcirc" },
    { { HTML_PLUS }, { HTML_UNDEF }, "hearts" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "heartsuit" },
    { { HTML_PLUS }, { HTML_UNDEF }, "hellip", "…" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hercon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hksearow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hkswarow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hoarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "homtht" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hookleftarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hookrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "horbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hslash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hstrok" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ht", "\t" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hybull" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "hyphen" },
    { { HTML_1_0 }, { HTML_UNDEF }, "iacute", "í" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ic" },
    { { HTML_1_0 }, { HTML_UNDEF }, "icirc", "î" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "icy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iecy" },
    { { HTML_1_0 }, { HTML_UNDEF }, "iexcl", "¡" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iff" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ifr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "igrave", "ì" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ii" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iiiint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iiint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iinfin" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iiota" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ijlig" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "imacr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "image" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "imagline" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "imagpart" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "imath" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "imof" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "imped" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "in" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "incare" },
    { { HTML_3_0 }, { HTML_3_0 }, "inf", "∞" },
    { { HTML_PLUS }, { HTML_UNDEF }, "infin", "∞" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "infty", "∞" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "infintie" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "inodot" },
    { { HTML_PLUS }, { HTML_UNDEF }, "int" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "intcal" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "integers" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "intercal" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "intlarhk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "intprod" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iocy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iogon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iopf" },
    { { HTML_PLUS }, { HTML_UNDEF }, "iota" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iprod" },
    { { HTML_1_0 }, { HTML_UNDEF }, "iquest", "¿" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iscr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "isin" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "isinE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "isindot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "isins" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "isinsv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "isinv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "it" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "itilde" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "iukcy" },
    { { HTML_1_0 }, { HTML_UNDEF }, "iuml", "ï" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "jcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "jcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "jfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "jmath" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "jopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "jscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "jsercy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "jukcy" },
    { { HTML_PLUS }, { HTML_UNDEF }, "kappa" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "kappav" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "kcedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "kcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "kfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "kgreen" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "khcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "kjcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "kopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "kscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lAarr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "lArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lAtail" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lBarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lEg" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lHar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lacute" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "laemptyv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lagran" },
    { { HTML_PLUS }, { HTML_UNDEF }, "lambda" },
    { { HTML_PLUS }, { HTML_UNDEF }, "lang" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "langd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "langle" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lap" },
    { { HTML_1_0 }, { HTML_UNDEF }, "laquo", "«" },
    { { HTML_PLUS }, { HTML_UNDEF }, "larr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "larrb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "larrbfs" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "larrfs" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "larrhk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "larrlp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "larrpl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "larrsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "larrtl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lat" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "latail" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "late" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lbarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lbbrk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lbrace" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lbrack" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lbrke" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lbrksld" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lbrkslu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lcedil" },
    { { HTML_PLUS }, { HTML_UNDEF }, "lceil" },
    { { HTML_3_0 }, { HTML_UNDEF }, "lcub", "{" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ldca" },
    { { HTML_3_0 }, { HTML_3_0 }, "ldots" },
    { { HTML_4_0 }, { HTML_UNDEF }, "ldquo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ldquor" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ldrdhar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ldrushar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ldsh" },
    { { HTML_PLUS }, { HTML_UNDEF }, "le", "≤" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftarrowtail" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftharpoondown" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftharpoonup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftleftarrows" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftrightarrows" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftrightharpoons" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftrightsquigarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leftthreetimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leg" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "leqslant" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "les" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lescc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lesdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lesdoto" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lesdotor" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lesges" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lessapprox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lessdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lesseqgtr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lesseqqgtr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lessgtr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lesssim" },
    { { HTML_1_0 }, { HTML_UNDEF }, "lf", "\f" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lfisht" },
    { { HTML_PLUS }, { HTML_UNDEF }, "lfloor" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lg" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lgE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lhard" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lharu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lharul" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lhblk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ljcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ll" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "llarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "llcorner" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "llhard" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lltri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lmidot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lmoust" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lmoustache" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lnE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lnap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lnapprox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lne" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lneq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lneqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lnsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "loang" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "loarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lobrk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "longleftarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "longleftrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "longmapsto" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "longrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "looparrowleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "looparrowright" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lopar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "loplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lotimes" },
    { { HTML_PLUS }, { HTML_UNDEF }, "lowast" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lowbar" },
    { { HTML_PLUS }, { HTML_UNDEF }, "loz" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lozenge" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lozf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lpar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lparlt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lrarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lrcorner" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lrhar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lrhard" },
    { { HTML_2_0, HV_RFC_2070 | HV_NOT3 }, { HTML_UNDEF }, "lrm" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lrtri" },
    { { HTML_4_0 }, { HTML_UNDEF }, "lsaquo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lsh" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lsime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lsimg" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lsqb" },
    { { HTML_4_0 }, { HTML_UNDEF }, "lsquo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lsquor" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lstrok" },
    { { HTML_TAGS }, { HTML_UNDEF }, "lt", "<" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltcc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltcir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lthree" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltlarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltquest" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltrPar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltrie" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ltrif" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "lurdshar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "luruhar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mDDot" },
    { { HTML_1_0 }, { HTML_UNDEF }, "macr", "¯" },
    { { HTML_PLUS }, { HTML_PLUS }, "macron", "¯" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "male" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "malt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "maltese" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "map" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mapsto" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mapstodown" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mapstoleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mapstoup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "marker" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mcomma" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mcy" },
    { { HTML_3_0, HV_NOT32 }, { HTML_UNDEF }, "mdash", "—" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "measuredangle" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mho" },
    { { HTML_1_0 }, { HTML_UNDEF }, "micro", "µ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "midast" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "midcir" },
    { { HTML_1_0 }, { HTML_UNDEF }, "middot", "·" },
    { { HTML_PLUS }, { HTML_UNDEF }, "minus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "minusb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "minusd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "minusdu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mlcp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mldr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mnplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "models" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mstpos" },
    { { HTML_PLUS }, { HTML_UNDEF }, "mu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "multimap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "mumap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nLeftarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nLeftrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nRightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nVDash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nVdash" },
    { { HTML_PLUS }, { HTML_UNDEF }, "nabla" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nacute" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "napos" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "napprox" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "nasymp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "natur" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "natural" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "naturals" },
    { { HTML_1_0 }, { HTML_UNDEF }, "nbsp" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "nbump" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "nbumpe" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ncap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ncaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ncedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ncong" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ncup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ncy" },
    { { HTML_3_0, HV_NOT32 }, { HTML_UNDEF }, "ndash", "–" },
    { { HTML_PLUS }, { HTML_UNDEF }, "ne", "≠" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "neArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nearhk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nearr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nearrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nequiv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nesear" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "nesim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nexist" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nexists" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nge" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ngeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ngsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ngt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ngtr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nhArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nharr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nhpar" },
    { { HTML_PLUS }, { HTML_UNDEF }, "ni" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nis" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nisd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "niv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "njcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nlArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nlarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nldr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nle" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nleftarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nleftrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nleq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nless" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nlsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nlt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nltri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nltrie" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nmid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nopf" },
    { { HTML_1_0 }, { HTML_UNDEF }, "not", "¬" },
    { { HTML_PLUS }, { HTML_UNDEF }, "notin" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "notinva" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "notinvb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "notinvc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "notni" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "notniva" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "notnivb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "notnivc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "npar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nparallel" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "npolint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "npr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "npre" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nprcue" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nprec" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nrArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nrarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nrightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nrtri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nrtrie" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsccue" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nshortmid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nshortparallel" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsimeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsmid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nspar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsqsube" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsqsupe" },
    { { HTML_PLUS }, { HTML_UNDEF }, "nsub" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsube" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsubseteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsucc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsupe" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nsupseteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ntgl" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ntilde", "ñ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ntlg" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ntriangleleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ntrianglelefteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ntriangleright" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ntrianglerighteq" },
    { { HTML_PLUS }, { HTML_UNDEF }, "nu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "num" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "numero" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "numsp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nvDash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nvHarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nvdash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nvinfin" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nvlArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nvrArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nwArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nwarhk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nwarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nwarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "nwnear" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "oS" },
    { { HTML_1_0 }, { HTML_UNDEF }, "oacute", "ó" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "oast" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "obar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ocir" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ocirc", "ô" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ocy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "odash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "odblac" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "odiv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "odot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "odsold" },
    { { HTML_4_0 }, { HTML_UNDEF }, "oelig", "œ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ofcir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ofr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ogon" },
    { { HTML_PLUS }, { HTML_PLUS }, "ogr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ograve", "ò" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ogt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ohbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ohm" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "oint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "olarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "olcir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "olcross" },
    { { HTML_4_0 }, { HTML_UNDEF }, "oline" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "olt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "omacr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "omega" },
    { { HTML_4_0 }, { HTML_UNDEF }, "omicron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "omid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ominus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "oopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "opar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "operp" },
    { { HTML_PLUS }, { HTML_UNDEF }, "oplus" },
    { { HTML_PLUS }, { HTML_UNDEF }, "or" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "orarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ord" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "order" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "orderof" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ordf" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ordm" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "origof" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "oror" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "orslope" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "orv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "oscr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "oslash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "osol" },
    { { HTML_1_0 }, { HTML_UNDEF }, "otilde" },
    { { HTML_PLUS }, { HTML_UNDEF }, "otimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "otimesas" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ouml" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ovbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "par" },
    { { HTML_1_0 }, { HTML_UNDEF }, "para", "¶" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "parallel" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "parsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "parsl" },
    { { HTML_PLUS }, { HTML_UNDEF }, "part" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "percnt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "period" },
    { { HTML_4_0 }, { HTML_UNDEF }, "permil" },
    { { HTML_PLUS }, { HTML_UNDEF }, "perp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pertenk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pfr" },
    { { HTML_4_0 }, { HTML_UNDEF }, "phi" },
    { { HTML_PLUS }, { HTML_PLUS }, "phis" },
    { { HTML_PLUS }, { HTML_UNDEF }, "phiv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "phmmat" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "phone" },
    { { HTML_PLUS }, { HTML_UNDEF }, "pi", "π" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pitchfork" },
    { { HTML_PLUS }, { HTML_UNDEF }, "piv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "planck" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "planckh" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "plankv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "plus", "+" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "plusacir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "plusb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pluscir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "plusdo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "plusdu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pluse" },
    { { HTML_1_0 }, { HTML_UNDEF }, "plusmn", "±" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "plussim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "plustwo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pm" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pointint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "popf" },
    { { HTML_1_0 }, { HTML_UNDEF }, "pound", "£" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "prE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "prap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "prcue" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pre" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "prec" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "precapprox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "preccurlyeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "preceq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "precnapprox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "precneqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "precnsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "precsim" },
    { { HTML_4_0 }, { HTML_UNDEF }, "prime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "primes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "prnE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "prnap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "prnsim" },
    { { HTML_PLUS }, { HTML_UNDEF }, "prod" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "profalar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "profline" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "profsurf" },
    { { HTML_PLUS }, { HTML_UNDEF }, "prop" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "propto" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "prsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "prurel" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "pscr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "psi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "puncsp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "qfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "qint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "qopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "qprime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "qscr" },
    { { HTML_3_0 }, { HTML_3_0 }, "quad" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "quaternions" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "quatint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "quest" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "questeq" },
    { { HTML_1_0 }, { HTML_UNDEF }, "quot", "\"" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rAarr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "rArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rAtail" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rBarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rHar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "race" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "racute" },
    { { HTML_PLUS }, { HTML_UNDEF }, "radic" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "raemptyv" },
    { { HTML_PLUS }, { HTML_UNDEF }, "rang" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rangd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "range" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rangle" },
    { { HTML_1_0 }, { HTML_UNDEF }, "raquo", "»" },
    { { HTML_PLUS }, { HTML_UNDEF }, "rarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrbfs" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrfs" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrhk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrlp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrpl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrtl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rarrw" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ratail" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ratio" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rationals" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rbarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rbbrk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rbrace" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rbrack" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rbrke" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rbrksld" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rbrkslu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rcedil" },
    { { HTML_PLUS }, { HTML_UNDEF }, "rceil" },
    { { HTML_3_0 }, { HTML_UNDEF }, "rcub", "}" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rdca" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rdldhar" },
    { { HTML_4_0 }, { HTML_UNDEF }, "rdquo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rdquor" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rdsh" },
    { { HTML_PLUS }, { HTML_UNDEF }, "real" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "realine" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "realpart" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "reals" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rect" },
    { { HTML_1_0 }, { HTML_UNDEF }, "reg", "®" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rfisht" },
    { { HTML_PLUS }, { HTML_UNDEF }, "rfloor" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rhard" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rharu" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rharul" },
    { { HTML_PLUS }, { HTML_UNDEF }, "rho" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rhov" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rightarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rightarrowtail" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rightharpoondown" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rightharpoonup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rightleftarrows" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rightleftharpoons" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rightrightarrows" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rightsquigarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rightthreetimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ring" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "risingdotseq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rlarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rlhar" },
    { { HTML_2_0, HV_RFC_2070 | HV_NOT3 }, { HTML_UNDEF }, "rlm" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rmoust" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rmoustache" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rnmid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "roang" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "roarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "robrk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ropar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ropf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "roplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rotimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rpar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rpargt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rppolint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rrarr" },
    { { HTML_4_0 }, { HTML_UNDEF }, "rsaquo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rsh" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rsqb" },
    { { HTML_4_0 }, { HTML_UNDEF }, "rsquo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rsquor" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rthree" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rtimes" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rtri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rtrie" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rtrif" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rtriltri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ruluhar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "rx" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sacute" },
    { { HTML_4_0 }, { HTML_UNDEF }, "sbquo" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scap" },
    { { HTML_4_0 }, { HTML_UNDEF }, "scaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sccue" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sce" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scnE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scnap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scnsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scpolint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "scy" },
    { { HTML_PLUS }, { HTML_UNDEF }, "sdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sdotb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sdote" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "seArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "searhk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "searr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "searrow" },
    { { HTML_1_0 }, { HTML_UNDEF }, "sect", "§" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "semi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "seswar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "setminus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "setmn" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sext" },
    { { HTML_PLUS }, { HTML_PLUS }, "sfgr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sfrown" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sharp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "shchcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "shcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "shortmid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "shortparallel" },
    { { HTML_1_0 }, { HTML_UNDEF }, "shy" },
    { { HTML_PLUS }, { HTML_UNDEF }, "sigma" },
    { { HTML_4_0 }, { HTML_UNDEF }, "sigmaf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sigmav" },
    { { HTML_PLUS }, { HTML_UNDEF }, "sim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "simdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "simeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "simg" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "simgE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "siml" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "simlE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "simne" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "simplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "simrarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "slarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "smallsetminus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "smashp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "smeparsl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "smid" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "smile" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "smt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "smte" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "softcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sol" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "solb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "solbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sopf" },
    { { HTML_1_0 }, { HTML_UNDEF }, "sp", " " },
    { { HTML_PLUS }, { HTML_UNDEF }, "spades" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "spadesuit" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "spar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqcap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqcup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqsub" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqsube" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqsubset" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqsubseteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqsup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqsupe" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqsupset" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sqsupseteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "squ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "square" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "squarf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "squf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "srarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ssetmn" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ssmile" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sstarf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "star" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "starf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "straightepsilon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "straightphi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "strns" },
    { { HTML_PLUS }, { HTML_UNDEF }, "sub" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subdot" },
    { { HTML_PLUS }, { HTML_UNDEF }, "sube" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subedot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "submult" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subnE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subne" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subrarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subset" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subseteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subseteqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subsetneq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subsetneqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subsub" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "subsup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "succ" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "succapprox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "succcurlyeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "succeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "succnapprox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "succneqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "succnsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "succsim" },
    { { HTML_PLUS }, { HTML_UNDEF }, "sum" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "sung" },
    { { HTML_PLUS }, { HTML_UNDEF }, "sup" },
    { { HTML_1_0 }, { HTML_UNDEF }, "sup1" },
    { { HTML_1_0 }, { HTML_UNDEF }, "sup2" },
    { { HTML_1_0 }, { HTML_UNDEF }, "sup3" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supdsub" },
    { { HTML_PLUS }, { HTML_UNDEF }, "supe" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supedot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "suphsub" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "suplarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supmult" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supnE" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supne" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supset" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supseteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supseteqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supsetneq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supsetneqq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supsim" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supsub" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "supsup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "swArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "swarhk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "swarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "swarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "swnwar" },
    { { HTML_1_0 }, { HTML_UNDEF }, "szlig", "ß" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "target" },
    { { HTML_PLUS }, { HTML_UNDEF }, "tau" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tbrk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tcedil" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "telrec" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tfr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "there4" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "therefore" },
    { { HTML_4_0 }, { HTML_UNDEF }, "theta" },
    { { HTML_PLUS }, { HTML_PLUS }, "thetas" },
    { { HTML_4_0 }, { HTML_UNDEF }, "thetasym" },
    { { HTML_PLUS }, { HTML_UNDEF }, "thetav" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "thickapprox" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "thicksim" },
    { { HTML_3_0, HV_NOT32 }, { HTML_UNDEF }, "thinsp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "thkap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "thksim" },
    { { HTML_1_0 }, { HTML_UNDEF }, "thorn" },
    { { HTML_4_0 }, { HTML_UNDEF }, "tilde" },
    { { HTML_1_0 }, { HTML_UNDEF }, "times" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "timesb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "timesbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "timesd" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tint" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "toea" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "top" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "topbot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "topcir" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "topf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "topfork" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tosa" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tprime" },
    { { HTML_PLUS }, { HTML_UNDEF }, "trade", "™" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "triangle" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "triangledown" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "triangleleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "trianglelefteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "triangleq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "triangleright" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "trianglerighteq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tridot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "trie" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "triminus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "triplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "trisb" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tritime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "trpezium" },
    { { XHTML_1_0 }, { HTML_UNDEF }, "true" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tscy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tshcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "tstrok" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "twixt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "twoheadleftarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "twoheadrightarrow" },
    { { HTML_4_0 }, { HTML_UNDEF }, "uArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uHar" },
    { { HTML_1_0 }, { HTML_UNDEF }, "uacute", "ú" },
    { { HTML_PLUS }, { HTML_UNDEF }, "uarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ubrcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ubreve" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ucirc", "û" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ucy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "udarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "udblac" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "udhar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ufisht" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ufr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "ugrave", "ù" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uharl" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uharr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uhblk" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ulcorn" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ulcorner" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ulcrop" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ultri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "umacr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "uml", "¨" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uogon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uparrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "updownarrow" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "upharpoonleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "upharpoonright" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uplus" },
    { { HTML_PLUS }, { HTML_UNDEF }, "upsi" },
    { { HTML_4_0 }, { HTML_UNDEF }, "upsih" },
    { { HTML_4_0 }, { HTML_UNDEF }, "upsilon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "upuparrows" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "urcorn" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "urcorner" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "urcrop" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uring" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "urtri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "utdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "utilde" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "utri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "utrif" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uuarr" },
    { { HTML_1_0 }, { HTML_UNDEF }, "uuml", "ü" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "uwangle" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vBar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vBarv" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vDash" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vangrt" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "varepsilon" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "varkappa" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "varnothing" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "varphi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "varpi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "varpropto" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "varr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "varrho" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "varsigma" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vartheta" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vartriangleleft" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vartriangleright" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vdash" },
    { { HTML_3_0 }, { HTML_3_0 }, "vdots" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vee" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "veebar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "veeeq" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vellip" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "verbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vert" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vltri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vopf" },
    { { HTML_PLUS }, { HTML_PLUS }, "vprime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vprop" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vrtri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "vzigzag" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wedbar" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wedge" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wedgeq" },
    { { HTML_PLUS }, { HTML_UNDEF }, "weierp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wp" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wreath" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "wscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xcap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xcirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xcup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xdtri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xhArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xharr" },
    { { HTML_PLUS }, { HTML_UNDEF }, "xi" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xlArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xlarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xmap" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xnis" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xodot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xoplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xotime" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xrArr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xrarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xsqcup" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xuplus" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xutri" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xvee" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "xwedge" },
    { { HTML_1_0 }, { HTML_UNDEF }, "yacute" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "yacy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ycirc" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "ycy" },
    { { HTML_1_0 }, { HTML_UNDEF }, "yen", "¥" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "yfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "yicy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "yopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "yscr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "yucy" },
    { { HTML_1_0 }, { HTML_UNDEF }, "yuml" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zacute" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zcaron" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zdot" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zeetrf" },
    { { HTML_PLUS }, { HTML_UNDEF }, "zeta" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zfr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zhcy" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zigrarr" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zopf" },
    { { HTML_JAN05 }, { HTML_UNDEF }, "zscr" },
    { { HTML_2_0, HV_RFC_2070 | HV_NOT3 }, { HTML_UNDEF }, "zwj" },
    { { HTML_2_0, HV_RFC_2070 | HV_NOT3 }, { HTML_UNDEF }, "zwnj" },

    { { HTML_UNDEF }, { HTML_UNDEF }, nullptr, nullptr } };

typedef ssc_map < ::std::string, wotsit_t > vw_t;
vw_t wotsit;

void wotsit_init (nitpick& nits)
{   for (int index = 0; wotsit_table [index].wotsit_ != nullptr; ++index)
        if (wotsit.find (wotsit_table [index].wotsit_) != wotsit.end ())
        {   nits.pick (nit_symbol_aleady_defined, es_error, ec_program, "Program error: wotsit ", wotsit_table [index].wotsit_, " already defined"); }
        else
        wotsit.insert (vw_t::value_type (wotsit_table [index].wotsit_, wotsit_table [index])); }

void text_check (nitpick& nits, const html_version& v, const ::std::string& text)
{   nits.set_context (0, text);
    if (context.tell (e_error))
    {   char after = text.at (0);
        ::std::string::size_type equal = text.find ('=', 1);
        if (equal != ::std::string::npos) return; // probably an HREF param that hasn't been normalised
        if (text.length () > max_wotsit_len + 1)
        {   nits.pick (nit_bizarre_character_code, es_error, ec_parser, "&", text, "; is neither a known text entity nor a normalised URL");
            return; }
        if (v.is_2_or_more ())
        {   if (::std::string (ALPHABET HASHES).find (after) == ::std::string::npos) return;
            if (after == HASH)
            {   if (text.length () == 1)
                    nits.pick (nit_empty_denary_code, es_warning, ec_parser, "empty numeric character code");
                else
                {   after = text.at (1);
                    if ((after == 'x') || (after == 'X'))
                    {   if (text.length () == 2)
                            nits.pick (nit_empty_hex_code, es_warning, ec_parser, "empty hex character code");
                        else
                        {   after = text.at (2);
                            if (text.length () > 8)
                                nits.pick (nit_hex_too_long, es_warning, ec_parser, "hex character code too long");
                            else if (::std::string (HEX).find_first_of (after) == ::std::string::npos)
                                nits.pick (nit_dubious_denary, es_warning, ec_parser, "dubious hex character code");
                            else if (text.substr (2).find_first_not_of (HEX) != ::std::string::npos)
                                nits.pick (nit_invalid_denary, es_warning, ec_parser, "invalid hex character code"); } }
                    else if (text.length () > 7)
                        nits.pick (nit_denary_too_long, es_warning, ec_parser, "denary character code too long");
                    else if (::std::string (DENARY).find_first_of (after) == ::std::string::npos)
                        nits.pick (nit_dubious_denary, es_warning, ec_parser, " dubious denary character code");
                    else if (text.substr (1).find_first_not_of (DENARY) != ::std::string::npos)
                        nits.pick (nit_invalid_denary, es_warning, ec_parser, "invalid denary character code"); }
                return; } }
        vw_t::const_iterator i = wotsit.find (text.c_str ());
        if (i == wotsit.end ())
            nits.pick (nit_bizarre_character_code, es_error, ec_parser, "&", text, "; is neither a known text entity nor a normalised URL");
        else if (! does_apply (v, i -> second.first_, i -> second.last_))
            nits.pick (nit_code_unrecognised_here, es_warning, ec_parser, "&", text, "; is invalid in ", v.report ()); } }

void examine_character_code (const html_version& v, const ::std::string& text, bool& known, bool& invalid)
{   assert (! text.empty ());
    vw_t::const_iterator i = wotsit.find (text.c_str ());
    if (i != wotsit.end ())
        if (! may_apply (v, i -> second.first_, i -> second.last_)) invalid = true;
        else known = true; }

::std::string interpret_character_code (const html_version& v, const ::std::string& text, bool& known, bool& invalid)
{   assert (! text.empty ());
    vw_t::const_iterator i = wotsit.find (text.c_str ());
    if (i != wotsit.end ())
        if (! may_apply (v, i -> second.first_, i -> second.last_)) invalid = true;
        else
        {   known = true;
            if (i -> second.char_ != nullptr) return i -> second.char_; }
    ::std::string res ("&");
    res += text + ';';
    return res; }

::std::string interpret_character_code (const html_version& v, const ::std::string& text)
{   bool invalid = false;
    bool known = false;
    return interpret_character_code (v, text, known, invalid); }

::std::string interpret_character_code (nitpick& nits, const html_version& v, const ::std::string& text)
{   bool invalid = false;
    bool known = false;
    ::std::string res (interpret_character_code (v, text, known, invalid));
    if (invalid)
        nits.pick (nit_invalid_character_code, es_error, ec_parser, res, " is invalid in ", v.report ());
    else if (! known)
        nits.pick (nit_invalid_character_code, es_error, ec_parser, res, " is unrecognised");
    return res; }

::std::string interpret_character_number (const ::std::string& text)
{   assert (! text.empty ());
    unsigned int n = 0;
    for (auto ch : text)
    {   n *= 10;
        if ((ch >= '0') && (ch <= '9')) n += ch - '0';
        else return text;
        if (n > UINT_MAX / 4) return text; }
    return ::std::string (1, static_cast <char> (n)); }

bool is_naughty_number (nitpick& nits, const ::std::string& s, const int n)
{   if (n < 32)
        nits.pick (nit_not_iso_8859_1, ed_iso_8859_1, "https://en.wikipedia.org/wiki/ISO/IEC_8859-1", es_warning, ec_parser, quote (s), " is a control character");
    else if ((n >= 127) && (n <= 159))
        nits.pick (nit_not_iso_8859_1, ed_iso_8859_1, "https://en.wikipedia.org/wiki/ISO/IEC_8859-1", es_warning, ec_parser, quote (s), " is an invalid character code");
    else if ((n == 65534) || (n == 65535))
        nits.pick (nit_not_iso_8859_1, ed_41, "24.2 Character entity references for ISO 8859-1 characters", es_warning, ec_parser, quote (s), " is invalid");
    else return false;
    return true; }

::std::string interpret_character_number (nitpick& nits, const ::std::string& text)
{   assert (! text.empty ());
    unsigned int n = 0;
    ::std::string res = "&#";
    res += text;
    res += ';';
    for (auto ch : text)
    {   n *= 10;
        if ((ch >= '0') && (ch <= '9')) n += ch - '0';
        else
        {   nits.pick (nit_invalid_character_denary, ed_41, "24.2 Character entity references for ISO 8859-1 characters", es_error, ec_parser, quote (res), " is not a denary integer");
            return res; }
        if (n > UINT_MAX / 4)
        {   nits.pick (nit_denary_too_long, ed_41, "24.2 Character entity references for ISO 8859-1 characters", es_error, ec_parser, text, " is too big");
            return res; } }
    if (is_naughty_number (nits, res, n)) return res;
    return ::std::string (1, static_cast <char> (n)); }

::std::string interpret_character_hex (const ::std::string& text)
{   assert (! text.empty ());
    unsigned int n = 0;
    for (auto ch : text)
    {   n <<= 4;
        if ((ch >= '0') && (ch <= '9')) n += ch - '0';
        else if ((ch >= 'A') && (ch <= 'F')) n += ch - 'A' + 10;
        else if ((ch >= 'a') && (ch <= 'f')) n += ch - 'a' + 10;
        else return text;
        if (n > UINT_MAX / 4) return text; }
    return ::std::string (1, static_cast <char> (n)); }

::std::string interpret_character_hex (nitpick& nits, const ::std::string& text)
{   assert (! text.empty ());
    ::std::string res = "&#x";
    res += text;
    res += ';';
    unsigned int n = 0;
    for (auto ch : text)
    {   n <<= 4;
        if ((ch >= '0') && (ch <= '9')) n += ch - '0';
        else if ((ch >= 'A') && (ch <= 'F')) n += ch - 'A' + 10;
        else if ((ch >= 'a') && (ch <= 'f')) n += ch - 'a' + 10;
        else
        {   nits.pick (nit_invalid_character_hex, es_error, ec_parser, quote (res), " is not a hexadecimal integer");
            return res; }
        if (n > UINT_MAX / 4)
        {   nits.pick (nit_hex_too_long, es_error, ec_parser, text, " is too big");
            break; } }
    if (is_naughty_number (nits, res, n)) return res;
    return ::std::string (1, static_cast <char> (n)); }
