/*
ssc (static site checker)
Copyright (c) 2020,2021 Dylan Harris
https://dylanharris.org/

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public Licence as published by
the Free Software Foundation, either version 3 of the Licence, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public Licence for more details.

You should have received a copy of the GNU General Public
Licence along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#include "main/standard.h"
#include "schema/schema_name.h"

struct property_name
{   const char* name_ = nullptr;
    e_schema_property prop_;
#ifdef REQUIRE_CONSTRUCTOR
    property_name ( const char* name, const e_schema_property prop)
        : name_ (name), prop_ (prop) { }
#endif // REQUIRE_CONSTRUCTOR
};

property_name namtab [] =
{   { "about", sp_about },
    { "abridged", sp_abridged },
    { "abstract", sp_abstract },
    { "accelerationTime", sp_accelerationtime },
    { "acceptedAnswer", sp_acceptedanswer },
    { "acceptedOffer", sp_acceptedoffer },
    { "acceptedPaymentMethod", sp_acceptedpaymentmethod },
    { "acceptsReservations", sp_acceptsreservations },
    { "accessCode", sp_accesscode },
    { "accessMode", sp_accessmode },
    { "accessModeSufficient", sp_accessmodesufficient },
    { "accessibilityAPI", sp_accessibilityapi },
    { "accessibilityControl", sp_accessibilitycontrol },
    { "accessibilityFeature", sp_accessibilityfeature },
    { "accessibilityHazard", sp_accessibilityhazard },
    { "accessibilitySummary", sp_accessibilitysummary },
    { "accommodationCategory", sp_accommodationcategory },
    { "accommodationFloorPlan", sp_accommodationfloorplan },
    { "accountId", sp_accountid },
    { "accountMinimumInflow", sp_accountminimuminflow },
    { "accountOverdraftLimit", sp_accountoverdraftlimit },
    { "accountablePerson", sp_accountableperson },
    { "acquireLicensePage", sp_acquirelicensepage },
    { "acquiredFrom", sp_acquiredfrom },
    { "acrissCode", sp_acrisscode },
    { "action", sp_action },
    { "actionAccessibilityRequirement", sp_actionaccessibilityrequirement },
    { "actionApplication", sp_actionapplication },
    { "actionOption", sp_actionoption },
    { "actionPlatform", sp_actionplatform },
    { "actionStatus", sp_actionstatus },
    { "actionableFeedbackPolicy", sp_actionablefeedbackpolicy },
    { "activeIngredient", sp_activeingredient },
    { "activityDuration", sp_activityduration },
    { "activityFrequency", sp_activityfrequency },
    { "actor", sp_actor },
    { "addOn", sp_addon },
    { "additionalName", sp_additionalname },
    { "additionalNumberOfGuests", sp_additionalnumberofguests },
    { "additionalProperty", sp_additionalproperty },
    { "additionalType", sp_additionaltype },
    { "additionalVariable", sp_additionalvariable },
    { "address", sp_address },
    { "addressCountry", sp_addresscountry },
    { "addressLocality", sp_addresslocality },
    { "addressRegion", sp_addressregion },
    { "administrationRoute", sp_administrationroute },
    { "advanceBookingRequirement", sp_advancebookingrequirement },
    { "adverseOutcome", sp_adverseoutcome },
    { "affectedBy", sp_affectedby },
    { "affiliation", sp_affiliation },
    { "afterMedia", sp_aftermedia },
    { "agent", sp_agent },
    { "aggregateRating", sp_aggregaterating },
    { "aircraft", sp_aircraft },
    { "album", sp_album },
    { "albumProductionType", sp_albumproductiontype },
    { "albumRelease", sp_albumrelease },
    { "albumReleaseType", sp_albumreleasetype },
    { "alcoholWarning", sp_alcoholwarning },
    { "algorithm", sp_algorithm },
    { "alignmentType", sp_alignmenttype },
    { "alternateName", sp_alternatename },
    { "alternativeHeadline", sp_alternativeheadline },
    { "alumni", sp_alumni },
    { "alumniOf", sp_alumniof },
    { "amenityFeature", sp_amenityfeature },
    { "amount", sp_amount },
    { "amountOfThisGood", sp_amountofthisgood },
    { "announcementLocation", sp_announcementlocation },
    { "annualPercentageRate", sp_annualpercentagerate },
    { "answerCount", sp_answercount },
    { "antagonist", sp_antagonist },
    { "appearance", sp_appearance },
    { "applicableLocation", sp_applicablelocation },
    { "applicantContact", sp_applicantcontact },
    { "applicantLocationRequirements", sp_applicantlocationrequirements },
    { "applicationCategory", sp_applicationcategory },
    { "applicationDeadline", sp_applicationdeadline },
    { "applicationStartDate", sp_applicationstartdate },
    { "applicationSubCategory", sp_applicationsubcategory },
    { "applicationSuite", sp_applicationsuite },
    { "appliesToDeliveryMethod", sp_appliestodeliverymethod },
    { "appliesToPaymentMethod", sp_appliestopaymentmethod },
    { "archiveHeld", sp_archiveheld },
    { "areaServed", sp_areaserved },
    { "arrivalAirport", sp_arrivalairport },
    { "arrivalBoatTerminal", sp_arrivalboatterminal },
    { "arrivalBusStop", sp_arrivalbusstop },
    { "arrivalGate", sp_arrivalgate },
    { "arrivalPlatform", sp_arrivalplatform },
    { "arrivalStation", sp_arrivalstation },
    { "arrivalTerminal", sp_arrivalterminal },
    { "arrivalTime", sp_arrivaltime },
    { "artEdition", sp_artedition },
    { "artMedium", sp_artmedium },
    { "arterialBranch", sp_arterialbranch },
    { "artform", sp_artform },
    { "articleBody", sp_articlebody },
    { "articleSection", sp_articlesection },
    { "artist", sp_artist },
    { "artworkSurface", sp_artworksurface },
    { "aspect", sp_aspect },
    { "assemblyVersion", sp_assemblyversion },
    { "assess", sp_assess },
    { "assesses", sp_assesses },
    { "associatedAnatomy", sp_associatedanatomy },
    { "associatedArticle", sp_associatedarticle },
    { "associatedMedia", sp_associatedmedia },
    { "associatedPathophysiology", sp_associatedpathophysiology },
    { "athlete", sp_athlete },
    { "attendee", sp_attendee },
    { "audience", sp_audience },
    { "audienceType", sp_audiencetype },
    { "audio", sp_audio },
    { "authenticator", sp_authenticator },
    { "author", sp_author },
    { "availabeDeliveryMethod", sp_availabedeliverymethod },
    { "availability", sp_availability },
    { "availabilityEnds", sp_availabilityends },
    { "availabilityStarts", sp_availabilitystarts },
    { "availableAtOrFrom", sp_availableatorfrom },
    { "availableChannel", sp_availablechannel },
    { "availableDeliveryMethod", sp_availabledeliverymethod },
    { "availableFrom", sp_availablefrom },
    { "availableIn", sp_availablein },
    { "availableLanguage", sp_availablelanguage },
    { "availableLocation", sp_availablelocation },
    { "availableOnDevice", sp_availableondevice },
    { "availableService", sp_availableservice },
    { "availableStrength", sp_availablestrength },
    { "availableTest", sp_availabletest },
    { "availableThrough", sp_availablethrough },
    { "award", sp_award },
    { "awayTeam", sp_awayteam },
    { "background", sp_background },
    { "backstory", sp_backstory },
    { "bankAccountType", sp_bankaccounttype },
    { "baseSalary", sp_basesalary },
    { "bccRecipient", sp_bccrecipient },
    { "bed", sp_bed },
    { "beforeMedia", sp_beforemedia },
    { "beneficiaryBank", sp_beneficiarybank },
    { "benefitsSummaryUrl", sp_benefitssummaryurl },
    { "bestRating", sp_bestrating },
    { "billingAddress", sp_billingaddress },
    { "billingDuration", sp_billingduration },
    { "billingIncrement", sp_billingincrement },
    { "billingPeriod", sp_billingperiod },
    { "billingStart", sp_billingstart },
    { "biomechanicalClass", sp_biomechanicalclass },
    { "birthDate", sp_birthdate },
    { "birthPlace", sp_birthplace },
    { "bitrate", sp_bitrate },
    { "blogPost", sp_blogpost },
    { "bloodSupply", sp_bloodsupply },
    { "boardingGroup", sp_boardinggroup },
    { "boardingPolicy", sp_boardingpolicy },
    { "bodyLocation", sp_bodylocation },
    { "bodyType", sp_bodytype },
    { "bookEdition", sp_bookedition },
    { "bookFormat", sp_bookformat },
    { "bookingTime", sp_bookingtime },
    { "box", sp_box },
    { "branch", sp_branch },
    { "branchCode", sp_branchcode },
    { "brand", sp_brand },
    { "breadcrumb", sp_breadcrumb },
    { "breastfeedingWarning", sp_breastfeedingwarning },
    { "broadcastAffiliateOf", sp_broadcastaffiliateof },
    { "broadcastChannelId", sp_broadcastchannelid },
    { "broadcastDisplayName", sp_broadcastdisplayname },
    { "broadcastFrequency", sp_broadcastfrequency },
    { "broadcastFrequencyValue", sp_broadcastfrequencyvalue },
    { "broadcastOfEvent", sp_broadcastofevent },
    { "broadcastServiceTier", sp_broadcastservicetier },
    { "broadcastSignalModulation", sp_broadcastsignalmodulation },
    { "broadcastSubChannel", sp_broadcastsubchannel },
    { "broadcastTimezone", sp_broadcasttimezone },
    { "broadcaster", sp_broadcaster },
    { "broker", sp_broker },
    { "browserRequirements", sp_browserrequirements },
    { "busName", sp_busname },
    { "busNumber", sp_busnumber },
    { "businessDays", sp_businessdays },
    { "businessFunction", sp_businessfunction },
    { "buyer", sp_buyer },
    { "byArtist", sp_byartist },
    { "byDay", sp_byday },
    { "byMonth", sp_bymonth },
    { "byMonthDay", sp_bymonthday },
    { "byMonthWeek", sp_bymonthweek },
    { "callSign", sp_callsign },
    { "calories", sp_calories },
    { "candidate", sp_candidate },
    { "caption", sp_caption },
    { "carbohydrateContent", sp_carbohydratecontent },
    { "cargoVolume", sp_cargovolume },
    { "carrierRequirements", sp_carrierrequirements },
    { "cashBack", sp_cashback },
    { "catalogNumber", sp_cataloguenumber },
    { "category", sp_category },
    { "cause", sp_cause },
    { "causeOf", sp_causeof },
    { "ccRecipient", sp_ccrecipient },
    { "character", sp_character },
    { "characterAttribute", sp_characterattribute },
    { "characterName", sp_charactername },
    { "cheatCode", sp_cheatcode },
    { "checkinTime", sp_checkintime },
    { "checkoutTime", sp_checkouttime },
    { "childMaxAge", sp_childmaxage },
    { "childMinAge", sp_childminage },
    { "children", sp_children },
    { "cholesterolContent", sp_cholesterolcontent },
    { "circle", sp_circle },
    { "citation", sp_citation },
    { "claimReviewed", sp_claimreviewed },
    { "clinicalPharamcology", sp_clinicalpharamcology },
    { "clipNumber", sp_clipnumber },
    { "closes", sp_closes },
    { "coach", sp_coach },
    { "code", sp_code },
    { "codeRepository", sp_coderepository },
    { "codeSampleType", sp_codesampletype },
    { "codeValue", sp_codevalue },
    { "codingSystem", sp_codingsystem },
    { "colleague", sp_colleague },
    { "collectionSize", sp_collectionsize },
    { "color", sp_colour },
    { "colorist", sp_colourist },
    { "comment", sp_comment },
    { "commentCount", sp_commentcount },
    { "commentText", sp_commenttext },
    { "commentTime", sp_commenttime },
    { "competencyRequired", sp_competencyrequired },
    { "competitor", sp_competitor },
    { "composer", sp_composer },
    { "comprisedOf", sp_comprisedof },
    { "conditionsOfAccess", sp_conditionsofaccess },
    { "confirmationNumber", sp_confirmationnumber },
    { "connectedTo", sp_connectedto },
    { "constrainingProperty", sp_constrainingproperty },
    { "contactOption", sp_contactoption },
    { "contactPoint", sp_contactpoint },
    { "contactType", sp_contacttype },
    { "contactlessPayment", sp_contactlesspayment },
    { "containedIn", sp_containedin },
    { "containedInPlace", sp_containedinplace },
    { "containsPlace", sp_containsplace },
    { "containsSeason", sp_containsseason },
    { "contentLocation", sp_contentlocation },
    { "contentRating", sp_contentrating },
    { "contentReferenceTime", sp_contentreferencetime },
    { "contentSize", sp_contentsize },
    { "contentType", sp_contenttype },
    { "contentUrl", sp_contenturl },
    { "contraindication", sp_contraindication },
    { "contributor", sp_contributor },
    { "cookTime", sp_cooktime },
    { "cookingMethod", sp_cookingmethod },
    { "copyrightHolder", sp_copyrightholder },
    { "copyrightNotice", sp_copyrightnotice },
    { "copyrightYear", sp_copyrightyear },
    { "correction", sp_correction },
    { "correctionsPolicy", sp_correctionspolicy },
    { "cost", sp_cost },
    { "costCategory", sp_costcategory },
    { "costCurrency", sp_costcurrency },
    { "costOrigin", sp_costorigin },
    { "costPerUnit", sp_costperunit },
    { "countriesNotSupported", sp_countriesnotsupported },
    { "countriesSupported", sp_countriessupported },
    { "countryOfOrigin", sp_countryoforigin },
    { "courseCode", sp_coursecode },
    { "courseMode", sp_coursemode },
    { "coursePresequisites", sp_coursepresequisites },
    { "courseWorkload", sp_courseworkload },
    { "coverageEndTime", sp_coverageendtime },
    { "coverageStartTime", sp_coveragestarttime },
    { "creativeWorkStatus", sp_creativeworkstatus },
    { "creator", sp_creator },
    { "credentialCategory", sp_credentialcategory },
    { "creditText", sp_credittext },
    { "creditedTo", sp_creditedto },
    { "cssSelector", sp_cssselector },
    { "currenciesAccepted", sp_currenciesaccepted },
    { "currency", sp_currency },
    { "currentExchangeRate", sp_currentexchangerate },
    { "customer", sp_customer },
    { "cutoffTime", sp_cutofftime },
    { "cvdCollectionDate", sp_cvdcollectiondate },
    { "cvdFacilityCounty", sp_cvdfacilitycounty },
    { "cvdFacilityId", sp_cvdfacilityid },
    { "cvdNumBeds", sp_cvdnumbeds },
    { "cvdNumBedsOcc", sp_cvdnumbedsocc },
    { "cvdNumC19Died", sp_cvdnumc19died },
    { "cvdNumC19HOPats", sp_cvdnumc19hopats },
    { "cvdNumC19HospPats", sp_cvdnumc19hosppats },
    { "cvdNumC19MechVentPats", sp_cvdnumc19mechventpats },
    { "cvdNumC19OFMechVentPats", sp_cvdnumc19ofmechventpats },
    { "cvdNumC19OverflowPats", sp_cvdnumc19overflowpats },
    { "cvdNumICUBeds", sp_cvdnumicubeds },
    { "cvdNumICUBedsOcc", sp_cvdnumicubedsocc },
    { "cvdNumTotBeds", sp_cvdnumtotbeds },
    { "cvdNumVent", sp_cvdnumvent },
    { "cvdNumVentUse", sp_cvdnumventuse },
    { "dataFeedElement", sp_datafeedelement },
    { "dataset", sp_dataset },
    { "datasetTimeInterval", sp_datasettimeinterval },
    { "dateCreated", sp_datecreated },
    { "dateDeleted", sp_datedeleted },
    { "dateIssued", sp_dateissued },
    { "dateModified", sp_datemodified },
    { "datePosted", sp_dateposted },
    { "datePublished", sp_datepublished },
    { "dateRead", sp_dateread },
    { "dateReceived", sp_datereceived },
    { "dateSent", sp_datesent },
    { "dateVehicleFirstRegistered", sp_datevehiclefirstregistered },
    { "dateline", sp_dateline },
    { "dayOfWeek", sp_dayofweek },
    { "deathDate", sp_deathdate },
    { "deathPlace", sp_deathplace },
    { "defaultValue", sp_defaultvalue },
    { "deliveryAddress", sp_deliveryaddress },
    { "deliveryLeadTime", sp_deliveryleadtime },
    { "deliveryMethod", sp_deliverymethod },
    { "deliveryStatus", sp_deliverystatus },
    { "deliveryTime", sp_deliverytime },
    { "department", sp_department },
    { "departureAirport", sp_departureairport },
    { "departureBoatTerminal", sp_departureboatterminal },
    { "departureBusStop", sp_departurebusstop },
    { "departureGate", sp_departuregate },
    { "departurePlatform", sp_departureplatform },
    { "departureStation", sp_departurestation },
    { "departureTerminal", sp_departureterminal },
    { "departureTime", sp_departuretime },
    { "dependencies", sp_dependencies },
    { "depth", sp_depth },
    { "description", sp_description },
    { "diagnosis", sp_diagnosis },
    { "diagram", sp_diagram },
    { "diet", sp_diet },
    { "dietFeatures", sp_dietfeatures },
    { "differentialDiagnosis", sp_differentialdiagnosis },
    { "director", sp_director },
    { "disambiguatingDescription", sp_disambiguatingdescription },
    { "discount", sp_discount },
    { "discountCode", sp_discountcode },
    { "discountCurrency", sp_discountcurrency },
    { "discusses", sp_discusses },
    { "discussionUrl", sp_discussionurl },
    { "diseasePreventionInfo", sp_diseasepreventioninfo },
    { "diseaseSpreadStatistics", sp_diseasespreadstatistics },
    { "dissolutionDate", sp_dissolutiondate },
    { "distance", sp_distance },
    { "distinguishingSign", sp_distinguishingsign },
    { "distribution", sp_distribution },
    { "diversityPolicy", sp_diversitypolicy },
    { "diversityStaffingReport", sp_diversitystaffingreport },
    { "documentation", sp_documentation },
    { "doesNotShip", sp_doesnotship },
    { "domainIncludes", sp_domainincludes },
    { "domiciledMortgage", sp_domiciledmortgage },
    { "doorTime", sp_doortime },
    { "dosageForm", sp_dosageform },
    { "doseSchedule", sp_doseschedule },
    { "doseUnit", sp_doseunit },
    { "doseValue", sp_dosevalue },
    { "downPayment", sp_downpayment },
    { "downloadUrl", sp_downloadurl },
    { "downvoteCount", sp_downvotecount },
    { "drainsTo", sp_drainsto },
    { "driveWheelConfiguration", sp_drivewheelconfiguration },
    { "dropoffLocation", sp_dropofflocation },
    { "dropoffTime", sp_dropofftime },
    { "drug", sp_drug },
    { "drugClass", sp_drugclass },
    { "drugUnit", sp_drugunit },
    { "duns", sp_duns },
    { "duplicateTherapy", sp_duplicatetherapy },
    { "duration", sp_duration },
    { "durationOfWarranty", sp_durationofwarranty },
    { "duringMedia", sp_duringmedia },
    { "earlyPrepaymentPenalty", sp_earlyprepaymentpenalty },
    { "editEIDR", sp_editeidr },
    { "editor", sp_editor },
    { "eduQuestionType", sp_eduquestiontype },
    { "educationCredentialAwarded", sp_educationcredentialawarded },
    { "educationRequirements", sp_educationrequirements },
    { "educationalAlignment", sp_educationalalignment },
    { "educationalCredentialAwarded", sp_educationalcredentialawarded },
    { "educationalFramework", sp_educationalframework },
    { "educationalLevel", sp_educationallevel },
    { "educationalProgramMode", sp_educationalprogrammode },
    { "educationalRole", sp_educationalrole },
    { "educationalUse", sp_educationaluse },
    { "elevation", sp_elevation },
    { "eligibileCustomerType", sp_eligibilecustomertype },
    { "eligibilityToWorkRequirement", sp_eligibilitytoworkrequirement },
    { "eligibleCustomerType", sp_eligiblecustomertype },
    { "eligibleDuration", sp_eligibleduration },
    { "eligibleQuantity", sp_eligiblequantity },
    { "eligibleRegion", sp_eligibleregion },
    { "eligibleTransactionVolume", sp_eligibletransactionvolume },
    { "email", sp_email },
    { "embedUrl", sp_embedurl },
    { "emmissionsCO2", sp_emmissionsco2 },
    { "employee", sp_employee },
    { "employerOverview", sp_employeroverview },
    { "employmentType", sp_employmenttype },
    { "employmentUnit", sp_employmentunit },
    { "encodesCreativeWork", sp_encodescreativework },
    { "encoding", sp_encoding },
    { "encodingFormat", sp_encodingformat },
    { "encodingType", sp_encodingtype },
    { "endDate", sp_enddate },
    { "endOffset", sp_endoffset },
    { "endTime", sp_endtime },
    { "endorsee", sp_endorsee },
    { "endorsers", sp_endorsers },
    { "energyEfficiencyScaleMax", sp_energyefficiencyscalemax },
    { "energyEfficiencyScaleMin", sp_energyefficiencyscalemin },
    { "engineDisplacement", sp_enginedisplacement },
    { "enginePower", sp_enginepower },
    { "engineType", sp_enginetype },
    { "entertainmentBusiness", sp_entertainmentbusiness },
    { "epidemiology", sp_epidemiology },
    { "episode", sp_episode },
    { "episodeNumber", sp_episodenumber },
    { "equal", sp_equal },
    { "error", sp_error },
    { "estimatedCost", sp_estimatedcost },
    { "estimatedFlightDuration", sp_estimatedflightduration },
    { "estimatedSalary", sp_estimatedsalary },
    { "estimatesRiskOf", sp_estimatesriskof },
    { "ethicsPolicy", sp_ethicspolicy },
    { "event", sp_event },
    { "eventAttendanceMode", sp_eventattendancemode },
    { "eventSchedule", sp_eventschedule },
    { "eventStatus", sp_eventstatus },
    { "evidenceLevel", sp_evidencelevel },
    { "evidenceOrigin", sp_evidenceorigin },
    { "exampleOfWork", sp_exampleofwork },
    { "exceptDate", sp_exceptdate },
    { "exchangeRateSpread", sp_exchangeratespread },
    { "executableLibraryName", sp_executablelibraryname },
    { "exerciseCourse", sp_exercisecourse },
    { "exercisePlan", sp_exerciseplan },
    { "exerciseRelatedDiet", sp_exerciserelateddiet },
    { "exerciseType", sp_exercisetype },
    { "exifData", sp_exifdata },
    { "expectedArrivalFrom", sp_expectedarrivalfrom },
    { "expectedArrivalUntil", sp_expectedarrivaluntil },
    { "expectedPrognosis", sp_expectedprognosis },
    { "expectsAcceptanceOf", sp_expectsacceptanceof },
    { "expeienceRequirements", sp_expeiencerequirements },
    { "experienceRequirements", sp_experiencerequirements },
    { "expires", sp_expires },
    { "exportConsiderations", sp_exportconsiderations },
    { "familyName", sp_familyname },
    { "fatContent", sp_fatcontent },
    { "faxNumber", sp_faxnumber },
    { "featureList", sp_featurelist },
    { "feesAndCommissionsSpecification", sp_feesandcommissionsspecification },
    { "fiberContent", sp_fibrecontent },
    { "fileFormat", sp_fileformat },
    { "fileSize", sp_filesize },
    { "financialAidEligible", sp_financialaideligible },
    { "firstAppearance", sp_firstappearance },
    { "firstPerformance", sp_firstperformance },
    { "flightDistance", sp_flightdistance },
    { "flightNumber", sp_flightnumber },
    { "floorLevel", sp_floorlevel },
    { "floorLimit", sp_floorlimit },
    { "floorSize", sp_floorsize },
    { "followee", sp_followee },
    { "follows", sp_follows },
    { "followup", sp_followup },
    { "foodEstablishment", sp_foodestablishment },
    { "foodEvent", sp_foodevent },
    { "foodWarning", sp_foodwarning },
    { "founder", sp_founder },
    { "foundingDate", sp_foundingdate },
    { "foundingLocation", sp_foundinglocation },
    { "freeShippingThreshold", sp_freeshippingthreshold },
    { "frequency", sp_frequency },
    { "fromLocation", sp_fromlocation },
    { "fuelCapacity", sp_fuelcapacity },
    { "fuelConsumption", sp_fuelconsumption },
    { "fuelEfficiency", sp_fuelefficiency },
    { "fuelType", sp_fueltype },
    { "funcionalClass", sp_funcionalclass },
    { "function", sp_function },
    { "fundedItem", sp_fundeditem },
    { "funder", sp_funder },
    { "game", sp_game },
    { "gameItem", sp_gameitem },
    { "gameLocation", sp_gamelocation },
    { "gamePlatform", sp_gameplatform },
    { "gameServer", sp_gameserver },
    { "gameTip", sp_gametip },
    { "gender", sp_gender },
    { "genre", sp_genre },
    { "geo", sp_geo },
    { "geoContains", sp_geocontains },
    { "geoCoveredBy", sp_geocoveredby },
    { "geoCovers", sp_geocovers },
    { "geoCrosses", sp_geocrosses },
    { "geoDisjoint", sp_geodisjoint },
    { "geoEquals", sp_geoequals },
    { "geoIntersects", sp_geointersects },
    { "geoMidpoint", sp_geomidpoint },
    { "geoOverlaps", sp_geooverlaps },
    { "geoRadius", sp_georadius },
    { "geoTouches", sp_geotouches },
    { "geoWithin", sp_geowithin },
    { "geographicArea", sp_geographicarea },
    { "gettingTestedInfo", sp_gettingtestedinfo },
    { "givenName", sp_givenname },
    { "globalLocationNumber", sp_globallocationnumber },
    { "governmentBenefitsInfo", sp_governmentbenefitsinfo },
    { "gracePeriod", sp_graceperiod },
    { "grantee", sp_grantee },
    { "greater", sp_greater },
    { "greaterOrEqual", sp_greaterorequal },
    { "gtin", sp_gtin },
    { "gtin12", sp_gtin12 },
    { "gtin13", sp_gtin13 },
    { "gtin14", sp_gtin14 },
    { "gtin8", sp_gtin8 },
    { "guideline", sp_guideline },
    { "guidelineDate", sp_guidelinedate },
    { "guidelineSubject", sp_guidelinesubject },
    { "handlingTime", sp_handlingtime },
    { "hasBroadcastChannel", sp_hasbroadcastchannel },
    { "hasCategoryCode", sp_hascategorycode },
    { "hasCourse", sp_hascourse },
    { "hasCourseInstance", sp_hascourseinstance },
    { "hasCredential", sp_hascredential },
    { "hasDefinedTerm", sp_hasdefinedterm },
    { "hasDeliveryMethod", sp_hasdeliverymethod },
    { "hasDigitalDocumentPermission", sp_hasdigitaldocumentpermission },
    { "hasDriveThroughService", sp_hasdrivethroughservice },
    { "hasEnergyConsumptionDetails", sp_hasenergyconsumptiondetails },
    { "hasEnergyEfficiencyCategory", sp_hasenergyefficiencycategory },
    { "hasHealthAspect", sp_hashealthaspect },
    { "hasMap", sp_hasmap },
    { "hasMeasurement", sp_hasmeasurement },
    { "hasMenu", sp_hasmenu },
    { "hasMenuItem", sp_hasmenuitem },
    { "hasMenuSection", sp_hasmenusection },
    { "hasMerchantReturnPolicy", sp_hasmerchantreturnpolicy },
    { "hasOccupation", sp_hasoccupation },
    { "hasOfferCatalog", sp_hasoffercatalogue },
    { "hasPOS", sp_haspos },
    { "hasPart", sp_haspart },
    { "hasProductReturnPolicy", sp_hasproductreturnpolicy },
    { "hasVariant", sp_hasvariant },
    { "headline", sp_headline },
    { "healthCondition", sp_healthcondition },
    { "healthPlanCoinsuranceOption", sp_healthplancoinsuranceoption },
    { "healthPlanCoinsuranceRate", sp_healthplancoinsurancerate },
    { "healthPlanCopay", sp_healthplancopay },
    { "healthPlanCopayOption", sp_healthplancopayoption },
    { "healthPlanCostSharing", sp_healthplancostsharing },
    { "healthPlanDrugOption", sp_healthplandrugoption },
    { "healthPlanDrugTier", sp_healthplandrugtier },
    { "healthPlanId", sp_healthplanid },
    { "healthPlanMarketingUrl", sp_healthplanmarketingurl },
    { "healthPlanNetworkId", sp_healthplannetworkid },
    { "healthPlanNetworkTier", sp_healthplannetworktier },
    { "healthPlanPharmacyCategory", sp_healthplanpharmacycategory },
    { "healthcareReportingData", sp_healthcarereportingdata },
    { "height", sp_height },
    { "highPrice", sp_highprice },
    { "hiringOrganization", sp_hiringorganization },
    { "holdingArchive", sp_holdingarchive },
    { "homeLocation", sp_homelocation },
    { "homeTeam", sp_hometeam },
    { "honorificPrefix", sp_honourificprefix },
    { "honorificSuffix", sp_honourificsuffix },
    { "hospitalAffiliation", sp_hospitalaffiliation },
    { "hostingOrganization", sp_hostingorganisation },
    { "hoursAvailable", sp_hoursavailable },
    { "howPerformed", sp_howperformed },
    { "httpMethod", sp_httpmethod },
    { "iataCode", sp_iatacode },
    { "identifier", sp_identifier },
    { "identifyingExam", sp_identifyingexam },
    { "identifyingTest", sp_identifyingtest },
    { "illustrator", sp_illustrator },
    { "image", sp_image },
    { "imagingTechnique", sp_imagingtechnique },
    { "inAlbum", sp_inalbum },
    { "inBroadcastLineup", sp_inbroadcastlineup },
    { "inCodeSet", sp_incodeset },
    { "inDefinedTermSet", sp_indefinedtermset },
    { "inLanguage", sp_inlanguage },
    { "inPlaylist", sp_inplaylist },
    { "inProductGroupWithID", sp_inproductgroupwithid },
    { "inStoreReturnsOffered", sp_instorereturnsoffered },
    { "inSupportOf", sp_insupportof },
    { "incentiveCompensation", sp_incentivecompensation },
    { "includedComposition", sp_includedcomposition },
    { "includedDataCatalog", sp_includeddatacatalog },
    { "includedInHealthInsurancePlan", sp_includedinhealthinsuranceplan },
    { "includedRiskFactor", sp_includedriskfactor },
    { "includesAttraction", sp_includesattraction },
    { "includesHealthPlanFormulary", sp_includeshealthplanformulary },
    { "includesHealthPlanNetwork", sp_includeshealthplannetwork },
    { "includesObject", sp_includesobject },
    { "increasesRiskOf", sp_increasesriskof },
    { "indication", sp_indication },
    { "industry", sp_industry },
    { "ineligibleRegion", sp_ineligibleregion },
    { "infectiousAgent", sp_infectiousagent },
    { "infectiousAgentClass", sp_infectiousagentclass },
    { "inker", sp_inker },
    { "insertion", sp_insertion },
    { "installUrl", sp_installurl },
    { "instructor", sp_instructor },
    { "instrument", sp_instrument },
    { "intensity", sp_intensity },
    { "interactingDrug", sp_interactingdrug },
    { "interactionService", sp_interactionservice },
    { "interactionStatistic", sp_interactionstatistic },
    { "interactionType", sp_interactiontype },
    { "interactivityType", sp_interactivitytype },
    { "interestRate", sp_interestrate },
    { "inventoryLevel", sp_inventorylevel },
    { "inverseOf", sp_inverseof },
    { "isAcceptingNewPatients", sp_isacceptingnewpatients },
    { "isAccessibleForFree", sp_isaccessibleforfree },
    { "isAccessoryOrSparePartFor", sp_isaccessoryorsparepartfor },
    { "isAvailableGenerally", sp_isavailablegenerally },
    { "isBasedOn", sp_isbasedon },
    { "isBasedOnUrl", sp_isbasedonurl },
    { "isConsumableFor", sp_isconsumablefor },
    { "isFamilyFriendly", sp_isfamilyfriendly },
    { "isGift", sp_isgift },
    { "isLiveBroadcast", sp_islivebroadcast },
    { "isPartOf", sp_ispartof },
    { "isPlanForApartment", sp_isplanforapartment },
    { "isProprietary", sp_isproprietary },
    { "isRelatedTo", sp_isrelatedto },
    { "isResizable", sp_isresizable },
    { "isSimilarTo", sp_issimilarto },
    { "isUnlabelledFallback", sp_isunlabelledfallback },
    { "isVariantOf", sp_isvariantof },
    { "isbn", sp_isbn },
    { "isicV4", sp_isicv4 },
    { "isrcCode", sp_isrccode },
    { "issn", sp_issn },
    { "issueNumber", sp_issuenumber },
    { "issuedBy", sp_issuedby },
    { "issuedThrough", sp_issuedthrough },
    { "iswcCode", sp_iswccode },
    { "item", sp_item },
    { "itemCondition", sp_itemcondition },
    { "itemListElement", sp_itemlistelement },
    { "itemListOrder", sp_itemlistorder },
    { "itemLocation", sp_itemlocation },
    { "itemOffered", sp_itemoffered },
    { "itemReviewed", sp_itemreviewed },
    { "itemShipped", sp_itemshipped },
    { "itinerary", sp_itinerary },
    { "jobBenefits", sp_jobbenefits },
    { "jobImmediateStart", sp_jobimmediatestart },
    { "jobLocation", sp_joblocation },
    { "jobLocationType", sp_joblocationtype },
    { "jobStartDate", sp_jobstartdate },
    { "jobTitle", sp_jobtitle },
    { "jurisdiction", sp_jurisdiction },
    { "keywords", sp_keywords },
    { "knownVehicleDamages", sp_knownvehicledamages },
    { "knows", sp_knows },
    { "knowsAbout", sp_knowsabout },
    { "knowsLanguage", sp_knowslanguage },
    { "labelDetails", sp_labeldetails },
    { "landlord", sp_landlord },
    { "lastReviewed", sp_lastreviewed },
    { "latitude", sp_latitude },
    { "layoutImage", sp_layoutimage },
    { "learningResourceType", sp_learningresourcetype },
    { "leaseLength", sp_leaselength },
    { "legalName", sp_legalname },
    { "legalStatus", sp_legalstatus },
    { "legislationApplies", sp_legislationapplies },
    { "legislationChanges", sp_legislationchanges },
    { "legislationConsolidates", sp_legislationconsolidates },
    { "legislationDate", sp_legislationdate },
    { "legislationDateVersion", sp_legislationdateversion },
    { "legislationIdentifier", sp_legislationidentifier },
    { "legislationJurisdiction", sp_legislationjurisdiction },
    { "legislationLegalForce", sp_legislationlegalforce },
    { "legislationLegalValue", sp_legislationlegalvalue },
    { "legislationPassedBy", sp_legislationpassedby },
    { "legislationResponsible", sp_legislationresponsible },
    { "legislationTransposes", sp_legislationtransposes },
    { "legislationType", sp_legislationtype },
    { "leiCode", sp_leicode },
    { "lender", sp_lender },
    { "lesser", sp_lesser },
    { "lesserOrEqual", sp_lesserorequal },
    { "letterer", sp_letterer },
    { "license", sp_license },
    { "line", sp_line },
    { "linkRelationship", sp_linkrelationship },
    { "liveBlogUpdate", sp_liveblogupdate },
    { "loanMortgagaMandateAmount", sp_loanmortgagamandateamount },
    { "loanPaymentAmount", sp_loanpaymentamount },
    { "loanPaymentFrequency", sp_loanpaymentfrequency },
    { "loanRepaymentForm", sp_loanrepaymentform },
    { "loanTerm", sp_loanterm },
    { "loanType", sp_loantype },
    { "location", sp_location },
    { "locationCreated", sp_locationcreated },
    { "lodgingUnitDescription", sp_lodgingunitdescription },
    { "lodgingUnitType", sp_lodgingunittype },
    { "logo", sp_logo },
    { "longitude", sp_longitude },
    { "loser", sp_loser },
    { "lowPrice", sp_lowprice },
    { "lyricist", sp_lyricist },
    { "lyrics", sp_lyrics },
    { "mainContentOfPage", sp_maincontentofpage },
    { "mainEntity", sp_mainentity },
    { "mainEntityOfPage", sp_mainentityofpage },
    { "maintainer", sp_maintainer },
    { "makesOffer", sp_makesoffer },
    { "manufacturer", sp_manufacturer },
    { "mapType", sp_maptype },
    { "marginOfError", sp_marginoferror },
    { "masthead", sp_masthead },
    { "material", sp_material },
    { "materialExtent", sp_materialextent },
    { "mathExpression", sp_mathexpression },
    { "maxPrice", sp_maxprice },
    { "maxValue", sp_maxvalue },
    { "maximumAttendeeCapacity", sp_maximumattendeecapacity },
    { "maximumEnrollment", sp_maximumenrollment },
    { "maximumIntake", sp_maximumintake },
    { "maximumPhysicalAttendeeCapacity", sp_maximumphysicalattendeecapacity },
    { "maximumVirtualAttendeeCapacity", sp_maximumvirtualattendeecapacity },
    { "mealService", sp_mealservice },
    { "measuredProperty", sp_measuredproperty },
    { "measuredValue", sp_measuredvalue },
    { "measurementTechnique", sp_measurementtechnique },
    { "mechanismOfAction", sp_mechanismofaction },
    { "mediaAuthenticityCategory", sp_mediaauthenticitycategory },
    { "median", sp_median },
//    { "medicalAudience", sp_aspect },
    { "medicalAudience", sp_medicalaudience },
    { "medicalSpeciality", sp_medicalspeciality },
    { "medicineSystem", sp_medicinesystem },
    { "meetsEmissionStandard", sp_meetsemissionstandard },
    { "member", sp_member },
    { "memberOf", sp_memberof },
    { "membershipNumber", sp_membershipnumber },
    { "membershipPointsEarned", sp_membershippointsearned },
    { "memoryRequirements", sp_memoryrequirements },
    { "mentions", sp_mentions },
    { "menu", sp_menu },
    { "menuAddOn", sp_menuaddon },
    { "merchantReturnDays", sp_merchantreturndays },
    { "merchantReturnLink", sp_merchantreturnlink },
    { "messageAttachment", sp_messageattachment },
    { "mileageFromOdometer", sp_mileagefromodometer },
    { "minPrice", sp_minprice },
    { "minValue", sp_minvalue },
    { "minimumMonthlyRepaymentAmount", sp_minimummonthlyrepaymentamount },
    { "minimumPaymentDue", sp_minimumpaymentdue },
    { "missionCoveragePrioritiesPolicy", sp_missioncoverageprioritiespolicy },
    { "model", sp_model },
    { "modelDate", sp_modeldate },
    { "modifiedTime", sp_modifiedtime },
    { "mpn", sp_mpn },
    { "multipleValues", sp_multiplevalues },
    { "muscleAction", sp_muscleaction },
    { "musicArrangement", sp_musicarrangement },
    { "musicBy", sp_musicby },
    { "musicCompositionForm", sp_musiccompositionform },
    { "musicReleaseFormat", sp_musicreleaseformat },
    { "musicalKey", sp_musicalkey },
    { "naics", sp_naics },
    { "name", sp_name },
    { "nationality", sp_nationality },
    { "naturalProgression", sp_naturalprogression },
    { "nerve", sp_nerve },
    { "nerveMotor", sp_nervemotor },
    { "netWorth", sp_networth },
    { "newUpdatesAndGuideLines", sp_newupdatesandguidelines },
    { "nextItem", sp_nextitem },
    { "noBylinesPolicy", sp_nobylinespolicy },
    { "nonEqual", sp_nonequal },
    { "nonPropriatryName", sp_nonpropriatryname },
    { "nonProprietaryName", sp_nonproprietaryname },
    { "nonprofitStatus", sp_nonprofitstatus },
    { "normalRange", sp_normalrange },
    { "nsn", sp_nsn },
    { "numAdults", sp_numadults },
    { "numChildren", sp_numchildren },
    { "numConstraints", sp_numconstraints },
    { "numTracks", sp_numtracks },
    { "numberOfAccommodationUnits", sp_numberofaccommodationunits },
    { "numberOfAirbags", sp_numberofairbags },
    { "numberOfAvailableAccommodationUnits", sp_numberofavailableaccommodationunits },
    { "numberOfAxles", sp_numberofaxles },
    { "numberOfBathroomsTotal", sp_numberofbathroomstotal },
    { "numberOfBedrooms", sp_numberofbedrooms },
    { "numberOfBeds", sp_numberofbeds },
    { "numberOfCredits", sp_numberofcredits },
    { "numberOfDoors", sp_numberofdoors },
    { "numberOfEmployees", sp_numberofemployees },
    { "numberOfEpisodes", sp_numberofepisodes },
    { "numberOfForwardgears", sp_numberofforwardgears },
    { "numberOfFullBathrooms", sp_numberoffullbathrooms },
    { "numberOfItems", sp_numberofitems },
    { "numberOfLoanPayments", sp_numberofloanpayments },
    { "numberOfPages", sp_numberofpages },
    { "numberOfPartialBathrooms", sp_numberofpartialbathrooms },
    { "numberOfPlayers", sp_numberofplayers },
    { "numberOfPreviousowners", sp_numberofpreviousowners },
    { "numberOfRooms", sp_numberofrooms },
    { "numberOfSeasons", sp_numberofseasons },
    { "numberedPosition", sp_numberedposition },
    { "nutrition", sp_nutrition },
    { "object", sp_object },
    { "observationDate", sp_observationdate },
    { "observedNode", sp_observednode },
    { "ocaoCode", sp_ocaocode },
    { "occupancy", sp_occupancy },
    { "occupationLocation", sp_occupationlocation },
    { "occupationalCategory", sp_occupationalcategory },
    { "occupationalCredentialAwarded", sp_occupationalcredentialawarded },
    { "offerCount", sp_offercount },
    { "offeredBy", sp_offeredby },
    { "offers", sp_offers },
    { "offersPrescriptionByMail", sp_offersprescriptionbymail },
    { "openingHours", sp_openinghours },
    { "openingHoursSpecification", sp_openinghoursspecification },
    { "opens", sp_opens },
    { "operatingSystem", sp_operatingsystem },
    { "opponent", sp_opponent },
    { "orderDate", sp_orderdate },
    { "orderDelivery", sp_orderdelivery },
    { "orderItemNumber", sp_orderitemnumber },
    { "orderItemStatus", sp_orderitemstatus },
    { "orderNumber", sp_ordernumber },
    { "orderQuantity", sp_orderquantity },
    { "orderStatus", sp_orderstatus },
    { "orderedItem", sp_ordereditem },
    { "organizer", sp_organiser },
    { "origin", sp_origin },
    { "originAddress", sp_originaddress },
    { "originatesFrom", sp_originatesfrom },
    { "outcome", sp_outcome },
    { "overdosage", sp_overdosage },
    { "overview", sp_overview },
    { "ownedFrom", sp_ownedfrom },
    { "ownedThrough", sp_ownedthrough },
    { "ownershipFundingInfo", sp_ownershipfundinginfo },
    { "owns", sp_owns },
    { "pageEnd", sp_pageend },
    { "pageStart", sp_pagestart },
    { "pagination", sp_pagination },
    { "parent", sp_parent },
    { "parentItem", sp_parentitem },
    { "parentOrganization", sp_parentorganisation },
    { "parentService", sp_parentservice },
    { "partOfEpisode", sp_partofepisode },
    { "partOfInvoice", sp_partofinvoice },
    { "partOfSeason", sp_partofseason },
    { "partOfSeries", sp_partofseries },
    { "partOfSystem", sp_partofsystem },
    { "partOfTrip", sp_partoftrip },
    { "participant", sp_participant },
    { "partofOrder", sp_partoforder },
    { "partySize", sp_partysize },
    { "passengerPriorityStatus", sp_passengerprioritystatus },
    { "passengerSequenceNumber", sp_passengersequencenumber },
    { "pathophysiology", sp_pathophysiology },
    { "pattern", sp_pattern },
    { "payload", sp_payload },
    { "paymentAccepted", sp_paymentaccepted },
    { "paymentDue", sp_paymentdue },
    { "paymentDueDate", sp_paymentduedate },
    { "paymentMethod", sp_paymentmethod },
    { "paymentMethodId", sp_paymentmethodid },
    { "paymentStatus", sp_paymentstatus },
    { "paymentUrl", sp_paymenturl },
    { "penciler", sp_penciler },
    { "percentile10", sp_percentile10 },
    { "percentile25", sp_percentile25 },
    { "percentile75", sp_percentile75 },
    { "percentile90", sp_percentile90 },
    { "performTime", sp_performtime },
    { "performer", sp_performer },
    { "performerIn", sp_performerin },
    { "permissionType", sp_permissiontype },
    { "permissions", sp_permissions },
    { "permitAudience", sp_permitaudience },
    { "permittedUsage", sp_permittedusage },
    { "petsAllowed", sp_petsallowed },
    { "phase", sp_phase },
    { "phoneticText", sp_phonetictext },
    { "photo", sp_photo },
    { "physicalRequirement", sp_physicalrequirement },
    { "physiologicalBenefits", sp_physiologicalbenefits },
    { "pickupLocation", sp_pickuplocation },
    { "pickupTime", sp_pickuptime },
    { "playMode", sp_playmode },
    { "playerType", sp_playertype },
    { "playersOnline", sp_playersonline },
    { "polygon", sp_polygon },
    { "population", sp_population },
    { "populationType", sp_populationtype },
    { "position", sp_position },
    { "possibleComplication", sp_possiblecomplication },
    { "possibleTreatment", sp_possibletreatment },
    { "postOfficeBoxNumber", sp_postofficeboxnumber },
    { "postOp", sp_postop },
    { "postalCode", sp_postalcode },
    { "postalCodeBegin", sp_postalcodebegin },
    { "postalCodeEnd", sp_postalcodeend },
    { "postalCodePrefix", sp_postalcodeprefix },
    { "postalCodeRange", sp_postalcoderange },
    { "potentialAction", sp_potentialaction },
    { "preOp", sp_preop },
    { "predecessorOf", sp_predecessorof },
    { "pregnancyCategory", sp_pregnancycategory },
    { "pregnancyWarning", sp_pregnancywarning },
    { "prepTime", sp_preptime },
    { "preparation", sp_preparation },
    { "prescribingInfo", sp_prescribinginfo },
    { "prescriptionStatus", sp_prescriptionstatus },
    { "previousItem", sp_previousitem },
    { "previousStartDate", sp_previousstartdate },
    { "price", sp_price },
    { "priceComponent", sp_pricecomponent },
    { "priceComponentType", sp_pricecomponenttype },
    { "priceCurrency", sp_pricecurrency },
    { "priceRange", sp_pricerange },
    { "priceSpecification", sp_pricespecification },
    { "priceType", sp_pricetype },
    { "priceValidUntil", sp_pricevaliduntil },
    { "primaryImageOfPage", sp_primaryimageofpage },
    { "primaryPrevention", sp_primaryprevention },
    { "printColumn", sp_printcolumn },
    { "printEdition", sp_printedition },
    { "printPage", sp_printpage },
    { "printSection", sp_printsection },
    { "procedure", sp_procedure },
    { "procedureType", sp_proceduretype },
    { "processingTime", sp_processingtime },
    { "processorRequirements", sp_processorrequirements },
    { "producer", sp_producer },
    { "productGroupID", sp_productgroupid },
    { "productID", sp_productid },
    { "productSupported", sp_productsupported },
    { "productionCompany", sp_productioncompany },
    { "productionDate", sp_productiondate },
    { "proficiencyLevel", sp_proficiencylevel },
    { "programMembershipUse", sp_programmemembershipused },
    { "programName", sp_programmename },
    { "programPrequisites", sp_programprequisites },
    { "programType", sp_programtype },
    { "programmingLanguage", sp_programminglanguage },
    { "programmingModel", sp_programmingmodel },
    { "propertyID", sp_propertyid },
    { "propriatryName", sp_propriatryname },
    { "proprietaryName", sp_proprietaryname },
    { "proteinContent", sp_proteincontent },
    { "provider", sp_provider },
    { "providerMobility", sp_providermobility },
    { "providesBroadcastService", sp_providesbroadcastservice },
    { "providesService", sp_providesservice },
    { "publicAccess", sp_publicaccess },
    { "publicTransportClosuresInfo", sp_publictransportclosuresinfo },
    { "publication", sp_publication },
    { "publicationType", sp_publicationtype },
    { "publishedBy", sp_publishedby },
    { "publishedOn", sp_publishedon },
    { "publisher", sp_publisher },
    { "publisherImprint", sp_publisherimprint },
    { "publishingPrinciples", sp_publishingprinciples },
    { "purchaseDate", sp_purchasedate },
    { "purpose", sp_purpose },
    { "qualifications", sp_qualifications },
    { "quarantineGuidelines", sp_quarantineguidelines },
    { "query", sp_query },
    { "quest", sp_quest },
    { "question", sp_question },
    { "rangeIncludes", sp_rangeincludes },
    { "ratingCount", sp_ratingcount },
    { "ratingExplanation", sp_ratingexplanation },
    { "ratingValue", sp_ratingvalue },
    { "readBy", sp_readby },
    { "readonlyValue", sp_readonlyvalue },
    { "realEstateAgent", sp_realestateagent },
    { "recipe", sp_recipe },
    { "recipeCategory", sp_recipecategory },
    { "recipeCuisine", sp_recipecuisine },
    { "recipeIngredient", sp_recipeingredient },
    { "recipeInstructions", sp_recipeinstructions },
    { "recipeYield", sp_recipeyield },
    { "recipient", sp_recipient },
    { "recognisedBy", sp_recognisedby },
    { "recognisingAuthority", sp_recognisingauthority },
    { "recommendationStrength", sp_recommendationstrength },
    { "recommendedIntake", sp_recommendedintake },
    { "recordLabel", sp_recordlabel },
    { "recordedAs", sp_recordedas },
    { "recordedAt", sp_recordedat },
    { "recordedIn", sp_recordedin },
    { "recordingOf", sp_recordingof },
    { "recourseLoan", sp_recourseloan },
    { "referenceQuantity", sp_referencequantity },
    { "referencesOrder", sp_referencesorder },
    { "refundType", sp_refundtype },
    { "regionDrained", sp_regiondrained },
    { "regionsAllowed", sp_regionsallowed },
    { "relatedAnatomy", sp_relatedanatomy },
    { "relatedCondition", sp_relatedcondition },
    { "relatedDrug", sp_relateddrug },
    { "relatedLink", sp_relatedlink },
    { "relatedStructure", sp_relatedstructure },
    { "relatedTherapy", sp_relatedtherapy },
    { "relatedTo", sp_relatedto },
    { "releaseDate", sp_releasedate },
    { "releaseNotes", sp_releasenotes },
    { "releaseOf", sp_releaseof },
    { "releasedEvent", sp_releasedevent },
    { "relevantOccupation", sp_relevantoccupation },
    { "relevantSpeciality", sp_relevantspeciality },
    { "remainingAttendeeCapacity", sp_remainingattendeecapacity },
    { "renegotiableLoan", sp_renegotiableloan },
    { "repeatCount", sp_repeatcount },
    { "repeatFrequency", sp_repeatfrequency },
    { "repetitions", sp_repetitions },
    { "replacee", sp_replacee },
    { "replacer", sp_replacer },
    { "replyToUrl", sp_replytourl },
    { "reportNumber", sp_reportnumber },
    { "representativeOfPage", sp_representativeofpage },
    { "requiredCollateral", sp_requiredcollateral },
    { "requiredGender", sp_requiredgender },
    { "requiredMaxAge", sp_requiredmaxage },
    { "requiredMinAge", sp_requiredminage },
    { "requiredQuantity", sp_requiredquantity },
    { "requiresSubscription", sp_requiressubscription },
    { "reservationFor", sp_reservationfor },
    { "reservationId", sp_reservationid },
    { "reservationStatus", sp_reservationstatus },
    { "reservedTicket", sp_reservedticket },
    { "responsibilities", sp_responsibilities },
    { "restPeriods", sp_restperiods },
    { "result", sp_result },
    { "resultComment", sp_resultcomment },
    { "resultReview", sp_resultreview },
    { "returnFees", sp_returnfees },
    { "returnPolicyCategory", sp_returnpolicycategory },
    { "review", sp_review },
    { "reviewAspect", sp_reviewaspect },
    { "reviewBody", sp_reviewbody },
    { "reviewCount", sp_reviewcount },
    { "reviewRating", sp_reviewrating },
    { "reviewedBy", sp_reviewedby },
    { "riskFactor", sp_riskfactor },
    { "risks", sp_risks },
    { "roleName", sp_rolename },
    { "roofLoad", sp_roofload },
    { "rsvpResponse", sp_rsvpresponse },
    { "runsTo", sp_runsto },
    { "runtimePlatform", sp_runtimeplatform },
    { "rxcui", sp_rxcui },
    { "safetyConsideration", sp_safetyconsideration },
    { "salaryCurrency", sp_salarycurrency },
    { "salaryUponCompletion", sp_salaryuponcompletion },
    { "sameAs", sp_sameas },
    { "saturatedFatContent", sp_saturatedfatcontent },
    { "scheduledPaymentDate", sp_scheduledpaymentdate },
    { "scheduledTime", sp_scheduledtime },
    { "schemaVersion", sp_schemaversion },
    { "schoolClosuresInfo", sp_schoolclosuresinfo },
    { "screenCount", sp_screencount },
    { "screenshot", sp_screenshot },
    { "sdDatePublished", sp_sddatepublished },
    { "sdLicense", sp_sdlicense },
    { "sdPublisher", sp_sdpublisher },
    { "seasonNumber", sp_seasonnumber },
    { "seatNumber", sp_seatnumber },
    { "seatRow", sp_seatrow },
    { "seatSection", sp_seatsection },
    { "seatingCapacity", sp_seatingcapacity },
    { "seatingType", sp_seatingtype },
    { "secondaryPrevention", sp_secondaryprevention },
    { "securityClearanceRequirement", sp_securityclearancerequirement },
    { "securityScreening", sp_securityscreening },
    { "seeks", sp_seeks },
    { "seller", sp_seller },
    { "sender", sp_sender },
    { "sensoryClearanceRequirement", sp_sensoryclearancerequirement },
    { "sensoryUnit", sp_sensoryunit },
    { "serialNumber", sp_serialnumber },
    { "seriousAdverseOutcome", sp_seriousadverseoutcome },
    { "serverStatus", sp_serverstatus },
    { "servesCuisine", sp_servescuisine },
    { "serviceArea", sp_servicearea },
    { "serviceLocation", sp_servicelocation },
    { "serviceOperator", sp_serviceoperator },
    { "serviceOutput", sp_serviceoutput },
    { "servicePhone", sp_servicephone },
    { "servicePostalAddress", sp_servicepostaladdress },
    { "serviceSmsNumber", sp_servicesmsnumber },
    { "serviceType", sp_servicetype },
    { "serviceUrl", sp_serviceurl },
    { "servingSize", sp_servingsize },
    { "sharedContent", sp_sharedcontent },
    { "shippingDestination", sp_shippingdestination },
    { "shippingLabel", sp_shippinglabel },
    { "shippingRate", sp_shippingrate },
    { "shippingSettingsLink", sp_shippingsettingslink },
    { "sibling", sp_sibling },
    { "signDetected", sp_signdetected },
    { "signOrSymptom", sp_signorsymptom },
    { "significance", sp_significance },
    { "significantLink", sp_significantlink },
    { "size", sp_size },
    { "sizeGroup", sp_sizegroup },
    { "sizeSystem", sp_sizesystem },
    { "skills", sp_skills },
    { "sku", sp_sku },
    { "slogan", sp_slogan },
    { "smokingAllowed", sp_smokingallowed },
    { "sodiumContent", sp_sodiumcontent },
    { "softwareAddOn", sp_softwareaddon },
    { "softwareHelp", sp_softwarehelp },
    { "softwareRequirements", sp_softwarerequirements },
    { "softwareVersion", sp_softwareversion },
    { "source", sp_source },
    { "sourceOrganization", sp_sourceorganisation },
    { "sourcedFrom", sp_sourcedfrom },
    { "spatial", sp_spatial },
    { "spatialCoverage", sp_spatialcoverage },
    { "speakable", sp_speakable },
    { "specialCommitments", sp_specialcommitments },
    { "specialOpeningHoursSpecification", sp_specialopeninghoursspecification },
    { "specialty", sp_speciality },
    { "speechToTextMarkup", sp_speechtotextmarkup },
    { "speed", sp_speed },
    { "spokenByCharacter", sp_spokenbycharacter },
    { "sponsor", sp_sponsor },
    { "sport", sp_sport },
    { "sportsActivityLocation", sp_sportsactivitylocation },
    { "sportsEvent", sp_sportsevent },
    { "sportsTeam", sp_sportsteam },
    { "spouse", sp_spouse },
    { "sscheduleTimezone", sp_scheduletimezone },
    { "stage", sp_stage },
    { "stageAsNumber", sp_stageasnumber },
    { "starRating", sp_starrating },
    { "startDate", sp_startdate },
    { "startOffset", sp_startoffset },
    { "startTime", sp_starttime },
    { "status", sp_status },
    { "steeringPosition", sp_steeringposition },
    { "step", sp_step },
    { "stepValue", sp_stepvalue },
    { "steps", sp_steps },
    { "storageRequirements", sp_storagerequirements },
    { "streetAddress", sp_streetaddress },
    { "strengthUnit", sp_strengthunit },
    { "strengthValue", sp_strengthvalue },
    { "structuralClass", sp_structuralclass },
    { "study", sp_study },
    { "studyDesign", sp_studydesign },
    { "studyLocation", sp_studylocation },
    { "studySubject", sp_studysubject },
    { "stupidProperty", sp_stupidproperty },
    { "subEvent", sp_subevent },
    { "subOrganization", sp_suborganisation },
    { "subReservation", sp_subreservation },
    { "subStageSuffix", sp_substagesuffix },
    { "subStructure", sp_substructure },
    { "subTrip", sp_subtrip },
    { "subjectOf", sp_subjectof },
    { "subtitleLanguage", sp_subtitlelanguage },
    { "subtype", sp_subtype },
    { "successorOf", sp_successorof },
    { "sugarContent", sp_sugarcontent },
    { "suggestedAge", sp_suggestedage },
    { "suggestedAnswer", sp_suggestedanswer },
    { "suggestedGender", sp_suggestedgender },
    { "suggestedMaxAge", sp_suggestedmaxage },
    { "suggestedMeasurement", sp_suggestedmeasurement },
    { "suggestedMinAge", sp_suggestedminage },
    { "suitableForDiet", sp_suitablefordiet },
    { "superEvent", sp_superevent },
    { "supersededBy", sp_supersededby },
    { "supply", sp_supply },
    { "supplyTo", sp_supplyto },
    { "supportingData", sp_supportingdata },
    { "suspersededBy", sp_suspersededby },
    { "target", sp_target },
    { "targetCollection", sp_targetcollection },
    { "targetDescription", sp_targetdescription },
    { "targetName", sp_targetname },
    { "targetPlatform", sp_targetplatform },
    { "targetPopulation", sp_targetpopulation },
    { "targetUrl", sp_targeturl },
    { "taxID", sp_taxid },
    { "teaches", sp_teaches },
    { "telephone", sp_telephone },
    { "temporal", sp_temporal },
    { "temporalCoverage", sp_temporalcoverage },
    { "termCode", sp_termcode },
    { "termDuration", sp_termduration },
    { "termsOfService", sp_termsofservice },
    { "termsPerYear", sp_termsperyear },
    { "text", sp_text },
    { "textValue", sp_textvalue },
    { "thumbnail", sp_thumbnail },
    { "thumbnailUrl", sp_thumbnailurl },
    { "tickerSymbol", sp_tickersymbol },
    { "ticketNumber", sp_ticketnumber },
    { "ticketToken", sp_tickettoken },
    { "ticketedSeat", sp_ticketedseat },
    { "timeOfDay", sp_timeofday },
    { "timeRequired", sp_timerequired },
    { "timeToComplete", sp_timetocomplete },
    { "tissueSample", sp_tissuesample },
    { "title", sp_title },
    { "titleEIDR", sp_titleeidr },
    { "toLocation", sp_tolocation },
    { "toRecipient", sp_torecipient },
    { "tocContinuation", sp_toccontinuation },
    { "tocEntry", sp_tocentry },
    { "tongueWeight", sp_tongueweight },
    { "tool", sp_tool },
    { "torque", sp_torque },
    { "totalJobOpenings", sp_totaljobopenings },
    { "totalPaymentDue", sp_totalpaymentdue },
    { "totalPrice", sp_totalprice },
    { "totalTime", sp_totaltime },
    { "tourBookingPage", sp_tourbookingpage },
    { "touristType", sp_touristtype },
    { "track", sp_track },
    { "trackingNumber", sp_trackingnumber },
    { "trackingUrl", sp_trackingurl },
    { "trailer", sp_trailer },
    { "trailerWeight", sp_trailerweight },
    { "trainName", sp_trainname },
    { "trainNumber", sp_trainnumber },
    { "trainingSalary", sp_trainingsalary },
    { "transFatContent", sp_transfatcontent },
    { "transcript", sp_transcript },
    { "transitTime", sp_transittime },
    { "transitTimeLabel", sp_transittimelabel },
    { "translationOfWork", sp_translationofwork },
    { "translator", sp_translator },
    { "transmissionMethod", sp_transmissionmethod },
    { "travelBans", sp_travelbans },
    { "trialDesign", sp_trialdesign },
    { "tributary", sp_tributary },
    { "typeOfBed", sp_typeofbed },
    { "typeOfGood", sp_typeofgood },
    { "typicalAgeRange", sp_typicalagerange },
    { "typicalCreditsPerTerm", sp_typicalcreditsperterm },
    { "typicalTest", sp_typicaltest },
    { "underName", sp_undername },
    { "unitCode", sp_unitcode },
    { "unitText", sp_unittext },
    { "unnamedSourcesPolicy", sp_unnamedsourcespolicy },
    { "unsaturatedFatContent", sp_unsaturatedfatcontent },
    { "uploadDate", sp_uploaddate },
    { "upvoteCount", sp_upvotecount },
    { "url", sp_url },
    { "urlTemplate", sp_urltemplate },
    { "usageInfo", sp_usageinfo },
    { "usedToDiagnose", sp_usedtodiagnose },
    { "userInteractionCount", sp_userinteractioncount },
    { "usesDevice", sp_usesdevice },
    { "usesHealthPlanIdStandard", sp_useshealthplanidstandard },
    { "utterances", sp_utterances },
    { "validFor", sp_validfor },
    { "validFrom", sp_validfrom },
    { "validIn", sp_validin },
    { "validThrough", sp_validthrough },
    { "validUntil", sp_validuntil },
    { "value", sp_value },
    { "valueAddedTaxIncluded", sp_valueaddedtaxincluded },
    { "valueMaxLength", sp_valuemaxlength },
    { "valueMinLength", sp_valueminlength },
    { "valueName", sp_valuename },
    { "valuePattern", sp_valuepattern },
    { "valueReference", sp_valuereference },
    { "valueRequired", sp_valuerequired },
    { "variableMeasured", sp_variablemeasured },
    { "variablesMeasured", sp_variablesmeasured },
    { "variantCover", sp_variantcover },
    { "variesBy", sp_variesby },
    { "vatID", sp_vatid },
    { "vehicleConfiguration", sp_vehicleconfiguration },
    { "vehicleEngine", sp_vehicleengine },
    { "vehicleIdentificationNumber", sp_vehicleidentificationnumber },
    { "vehicleInteriorColor", sp_vehicleinteriorcolour },
    { "vehicleInteriorType", sp_vehicleinteriortype },
    { "vehicleModelDate", sp_vehiclemodeldate },
    { "vehicleSeatingCapacity", sp_vehicleseatingcapacity },
    { "vehicleSpecialUsage", sp_vehiclespecialusage },
    { "vehicleTransmission", sp_vehicletransmission },
    { "verificationFactCheckingPolicy", sp_verificationfactcheckingpolicy },
    { "version", sp_version },
    { "video", sp_video },
    { "videoFormat", sp_videoformat },
    { "videoFrameSize", sp_videoframesize },
    { "videoQuality", sp_videoquality },
    { "volumeNumber", sp_volumenumber },
    { "warning", sp_warning },
    { "warranty", sp_warranty },
    { "warrantyScope", sp_warrantyscope },
    { "webCheckInTime", sp_webcheckintime },
    { "webFeed", sp_webfeed },
    { "weight", sp_weight },
    { "weightTotal", sp_weighttotal },
    { "wheelbase", sp_wheelbase },
    { "width", sp_width },
    { "winner", sp_winner },
    { "wordCount", sp_wordcount },
    { "workExample", sp_workexample },
    { "workFeatured", sp_workfeatured },
    { "workHours", sp_workhours },
    { "workLocation", sp_worklocation },
    { "workPerformed", sp_workperformed },
    { "workPresented", sp_workpresented },
    { "workTranslation", sp_worktranslation },
    { "workload", sp_workload },
    { "worksFor", sp_worksfor },
    { "worstRating", sp_worstrating },
    { "xpath", sp_xpath },
    { "yearBuilt", sp_yearbuilt },
    { "yearlyRevenue", sp_yearlyrevenue },
    { "yearsInOperation", sp_yearsinoperation },
    { "yield", sp_yield },
    { nullptr, sp_illegal } };

typedef ssc_map < ::std::string, e_schema_property > mpn_t;
typedef ssc_map < e_schema_property, ::std::string > mnp_t;
mpn_t mpn;
mnp_t mnp;

void schema_name_init (nitpick& nits)
{   assert (mpn.empty ());
    assert (mnp.empty ());
    for (property_name* p = &namtab [0]; p -> prop_ != sp_illegal; ++p)
        if (p -> name_ != nullptr)
        {   ::std::string n (::boost::to_lower_copy (::std::string (p -> name_)));
            if (mpn.find (n) != mpn.cend ())
                nits.pick (nit_symbol_aleady_defined, es_catastrophic, ec_init, "schema property name ", n, " defined more than once");
            else if (mnp.find (p -> prop_) != mnp.cend ())
                nits.pick (nit_symbol_aleady_defined, es_catastrophic, ec_init, "schema property ", p -> prop_, " given more than one name");
            else
            {   mpn.insert (mpn_t::value_type (n, p -> prop_));
                mnp.insert (mnp_t::value_type (p -> prop_, p -> name_)); } } }

::std::string schema_property_name (const e_schema_property p)
{   mnp_t::const_iterator i = mnp.find (p);
    if (i == mnp.cend ()) return ::std::string ();
    return i -> second; }

e_schema_property get_schema_property (const ::std::string& s)
{   mpn_t::const_iterator i = mpn.find (s);
    if (i == mpn.cend ()) return sp_illegal;
    return i -> second; }
